# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ManagedPolicy',
]


class ManagedPolicy(str, Enum):
    API_GATEWAY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/APIGatewayServiceRolePolicy"
    AWS_ACCOUNT_ACTIVITY_ACCESS = "arn:aws:iam::aws:policy/AWSAccountActivityAccess"
    AWS_ACCOUNT_MANAGEMENT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSAccountManagementFullAccess"
    AWS_ACCOUNT_MANAGEMENT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSAccountManagementReadOnlyAccess"
    AWS_ACCOUNT_USAGE_REPORT_ACCESS = "arn:aws:iam::aws:policy/AWSAccountUsageReportAccess"
    AWS_AGENTLESS_DISCOVERY_SERVICE = "arn:aws:iam::aws:policy/AWSAgentlessDiscoveryService"
    AWS_APP_MESH_ENVOY_ACCESS = "arn:aws:iam::aws:policy/AWSAppMeshEnvoyAccess"
    AWS_APP_MESH_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSAppMeshFullAccess"
    AWS_APP_MESH_PREVIEW_ENVOY_ACCESS = "arn:aws:iam::aws:policy/AWSAppMeshPreviewEnvoyAccess"
    AWS_APP_MESH_PREVIEW_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSAppMeshPreviewServiceRolePolicy"
    AWS_APP_MESH_READ_ONLY = "arn:aws:iam::aws:policy/AWSAppMeshReadOnly"
    AWS_APP_MESH_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSAppMeshServiceRolePolicy"
    AWS_APP_RUNNER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSAppRunnerFullAccess"
    AWS_APP_RUNNER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSAppRunnerReadOnlyAccess"
    AWS_APP_RUNNER_SERVICE_POLICY_FOR_ECR_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSAppRunnerServicePolicyForECRAccess"
    AWS_APP_SYNC_ADMINISTRATOR = "arn:aws:iam::aws:policy/AWSAppSyncAdministrator"
    AWS_APP_SYNC_INVOKE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSAppSyncInvokeFullAccess"
    AWS_APP_SYNC_PUSH_TO_CLOUD_WATCH_LOGS = "arn:aws:iam::aws:policy/service-role/AWSAppSyncPushToCloudWatchLogs"
    AWS_APP_SYNC_SCHEMA_AUTHOR = "arn:aws:iam::aws:policy/AWSAppSyncSchemaAuthor"
    AWS_APP_SYNC_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSAppSyncServiceRolePolicy"
    AWS_APPLICATION_AUTO_SCALING_CUSTOM_RESOURCE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoScalingCustomResourcePolicy"
    AWS_APPLICATION_AUTOSCALING_APP_STREAM_FLEET_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingAppStreamFleetPolicy"
    AWS_APPLICATION_AUTOSCALING_CASSANDRA_TABLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingCassandraTablePolicy"
    AWS_APPLICATION_AUTOSCALING_COMPREHEND_ENDPOINT_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingComprehendEndpointPolicy"
    AWS_APPLICATION_AUTOSCALING_DYNAMO_DB_TABLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingDynamoDBTablePolicy"
    AWS_APPLICATION_AUTOSCALING_EC2_SPOT_FLEET_REQUEST_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingEC2SpotFleetRequestPolicy"
    AWS_APPLICATION_AUTOSCALING_ECS_SERVICE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingECSServicePolicy"
    AWS_APPLICATION_AUTOSCALING_EMR_INSTANCE_GROUP_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingEMRInstanceGroupPolicy"
    AWS_APPLICATION_AUTOSCALING_ELASTI_CACHE_RG_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingElastiCacheRGPolicy"
    AWS_APPLICATION_AUTOSCALING_KAFKA_CLUSTER_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingKafkaClusterPolicy"
    AWS_APPLICATION_AUTOSCALING_LAMBDA_CONCURRENCY_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingLambdaConcurrencyPolicy"
    AWS_APPLICATION_AUTOSCALING_NEPTUNE_CLUSTER_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingNeptuneClusterPolicy"
    AWS_APPLICATION_AUTOSCALING_RDS_CLUSTER_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingRDSClusterPolicy"
    AWS_APPLICATION_AUTOSCALING_SAGE_MAKER_ENDPOINT_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationAutoscalingSageMakerEndpointPolicy"
    AWS_APPLICATION_DISCOVERY_AGENT_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationDiscoveryAgentAccess"
    AWS_APPLICATION_DISCOVERY_AGENTLESS_COLLECTOR_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationDiscoveryAgentlessCollectorAccess"
    AWS_APPLICATION_DISCOVERY_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationDiscoveryServiceFullAccess"
    AWS_APPLICATION_MIGRATION_AGENT_INSTALLATION_POLICY = "arn:aws:iam::aws:policy/AWSApplicationMigrationAgentInstallationPolicy"
    AWS_APPLICATION_MIGRATION_AGENT_POLICY = "arn:aws:iam::aws:policy/AWSApplicationMigrationAgentPolicy"
    AWS_APPLICATION_MIGRATION_AGENT_POLICY_V2 = "arn:aws:iam::aws:policy/service-role/AWSApplicationMigrationAgentPolicy_v2"
    AWS_APPLICATION_MIGRATION_CONVERSION_SERVER_POLICY = "arn:aws:iam::aws:policy/service-role/AWSApplicationMigrationConversionServerPolicy"
    AWS_APPLICATION_MIGRATION_EC2_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationMigrationEC2Access"
    AWS_APPLICATION_MIGRATION_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationMigrationFullAccess"
    AWS_APPLICATION_MIGRATION_MGH_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSApplicationMigrationMGHAccess"
    AWS_APPLICATION_MIGRATION_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationMigrationReadOnlyAccess"
    AWS_APPLICATION_MIGRATION_REPLICATION_SERVER_POLICY = "arn:aws:iam::aws:policy/service-role/AWSApplicationMigrationReplicationServerPolicy"
    AWS_APPLICATION_MIGRATION_SSM_ACCESS = "arn:aws:iam::aws:policy/AWSApplicationMigrationSSMAccess"
    AWS_APPLICATION_MIGRATION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSApplicationMigrationServiceRolePolicy"
    AWS_APPLICATION_MIGRATION_V_CENTER_CLIENT_POLICY = "arn:aws:iam::aws:policy/AWSApplicationMigrationVCenterClientPolicy"
    AWS_ARTIFACT_ACCOUNT_SYNC = "arn:aws:iam::aws:policy/service-role/AWSArtifactAccountSync"
    AWS_AUDIT_MANAGER_ADMINISTRATOR_ACCESS = "arn:aws:iam::aws:policy/AWSAuditManagerAdministratorAccess"
    AWS_AUDIT_MANAGER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSAuditManagerServiceRolePolicy"
    AWS_AUTO_SCALING_PLANS_EC2_AUTO_SCALING_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSAutoScalingPlansEC2AutoScalingPolicy"
    AWS_BACKUP_AUDIT_ACCESS = "arn:aws:iam::aws:policy/AWSBackupAuditAccess"
    AWS_BACKUP_DATA_TRANSFER_ACCESS = "arn:aws:iam::aws:policy/AWSBackupDataTransferAccess"
    AWS_BACKUP_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSBackupFullAccess"
    AWS_BACKUP_GATEWAY_SERVICE_ROLE_POLICY_FOR_VIRTUAL_MACHINE_METADATA_SYNC = "arn:aws:iam::aws:policy/service-role/AWSBackupGatewayServiceRolePolicyForVirtualMachineMetadataSync"
    AWS_BACKUP_OPERATOR_ACCESS = "arn:aws:iam::aws:policy/AWSBackupOperatorAccess"
    AWS_BACKUP_ORGANIZATION_ADMIN_ACCESS = "arn:aws:iam::aws:policy/AWSBackupOrganizationAdminAccess"
    AWS_BACKUP_RESTORE_ACCESS_FOR_SAPHANA = "arn:aws:iam::aws:policy/AWSBackupRestoreAccessForSAPHANA"
    AWS_BACKUP_SERVICE_LINKED_ROLE_POLICY_FOR_BACKUP = "arn:aws:iam::aws:policy/aws-service-role/AWSBackupServiceLinkedRolePolicyForBackup"
    AWS_BACKUP_SERVICE_LINKED_ROLE_POLICY_FOR_BACKUP_TEST = "arn:aws:iam::aws:policy/aws-service-role/AWSBackupServiceLinkedRolePolicyForBackupTest"
    AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_BACKUP = "arn:aws:iam::aws:policy/service-role/AWSBackupServiceRolePolicyForBackup"
    AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_RESTORES = "arn:aws:iam::aws:policy/service-role/AWSBackupServiceRolePolicyForRestores"
    AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_BACKUP = "arn:aws:iam::aws:policy/AWSBackupServiceRolePolicyForS3Backup"
    AWS_BACKUP_SERVICE_ROLE_POLICY_FOR_S3_RESTORE = "arn:aws:iam::aws:policy/AWSBackupServiceRolePolicyForS3Restore"
    AWS_BATCH_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSBatchFullAccess"
    AWS_BATCH_SERVICE_EVENT_TARGET_ROLE = "arn:aws:iam::aws:policy/service-role/AWSBatchServiceEventTargetRole"
    AWS_BATCH_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSBatchServiceRole"
    AWS_BILLING_CONDUCTOR_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSBillingConductorFullAccess"
    AWS_BILLING_CONDUCTOR_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSBillingConductorReadOnlyAccess"
    AWS_BILLING_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSBillingReadOnlyAccess"
    AWS_BUDGETS_ACTIONS_WITH_AWS_RESOURCE_CONTROL_ACCESS = "arn:aws:iam::aws:policy/AWSBudgetsActionsWithAWSResourceControlAccess"
    AWS_BUDGETS_ACTIONS_ROLE_POLICY_FOR_RESOURCE_ADMINISTRATION_WITH_SSM = "arn:aws:iam::aws:policy/AWSBudgetsActions_RolePolicyForResourceAdministrationWithSSM"
    AWS_BUDGETS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSBudgetsReadOnlyAccess"
    AWS_BUG_BUST_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSBugBustFullAccess"
    AWS_BUG_BUST_PLAYER_ACCESS = "arn:aws:iam::aws:policy/AWSBugBustPlayerAccess"
    AWS_BUG_BUST_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSBugBustServiceRolePolicy"
    AWS_CERTIFICATE_MANAGER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCertificateManagerFullAccess"
    AWS_CERTIFICATE_MANAGER_PRIVATE_CA_AUDITOR = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAAuditor"
    AWS_CERTIFICATE_MANAGER_PRIVATE_CA_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAFullAccess"
    AWS_CERTIFICATE_MANAGER_PRIVATE_CA_PRIVILEGED_USER = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAPrivilegedUser"
    AWS_CERTIFICATE_MANAGER_PRIVATE_CA_READ_ONLY = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAReadOnly"
    AWS_CERTIFICATE_MANAGER_PRIVATE_CAUSER = "arn:aws:iam::aws:policy/AWSCertificateManagerPrivateCAUser"
    AWS_CERTIFICATE_MANAGER_READ_ONLY = "arn:aws:iam::aws:policy/AWSCertificateManagerReadOnly"
    AWS_CHATBOT_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSChatbotServiceLinkedRolePolicy"
    AWS_CLEAN_ROOMS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCleanRoomsFullAccess"
    AWS_CLEAN_ROOMS_FULL_ACCESS_NO_QUERYING = "arn:aws:iam::aws:policy/AWSCleanRoomsFullAccessNoQuerying"
    AWS_CLEAN_ROOMS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCleanRoomsReadOnlyAccess"
    AWS_CLOUD9_ADMINISTRATOR = "arn:aws:iam::aws:policy/AWSCloud9Administrator"
    AWS_CLOUD9_ENVIRONMENT_MEMBER = "arn:aws:iam::aws:policy/AWSCloud9EnvironmentMember"
    AWS_CLOUD9_SSM_INSTANCE_PROFILE = "arn:aws:iam::aws:policy/AWSCloud9SSMInstanceProfile"
    AWS_CLOUD9_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSCloud9ServiceRolePolicy"
    AWS_CLOUD9_USER = "arn:aws:iam::aws:policy/AWSCloud9User"
    AWS_CLOUD_FORMATION_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudFormationFullAccess"
    AWS_CLOUD_FORMATION_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudFormationReadOnlyAccess"
    AWS_CLOUD_FRONT_LOGGER = "arn:aws:iam::aws:policy/aws-service-role/AWSCloudFrontLogger"
    AWS_CLOUD_HSM_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudHSMFullAccess"
    AWS_CLOUD_HSM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudHSMReadOnlyAccess"
    AWS_CLOUD_HSM_ROLE = "arn:aws:iam::aws:policy/service-role/AWSCloudHSMRole"
    AWS_CLOUD_TRAIL_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudTrailFullAccess"
    AWS_CLOUD_TRAIL_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudTrailReadOnlyAccess"
    AWS_CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY = "arn:aws:iam::aws:policy/AWSCloudWatchLambdaInsightsExecutionRolePolicy"
    AWS_CLOUD_MAP_DISCOVER_INSTANCE_ACCESS = "arn:aws:iam::aws:policy/AWSCloudMapDiscoverInstanceAccess"
    AWS_CLOUD_MAP_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudMapFullAccess"
    AWS_CLOUD_MAP_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudMapReadOnlyAccess"
    AWS_CLOUD_MAP_REGISTER_INSTANCE_ACCESS = "arn:aws:iam::aws:policy/AWSCloudMapRegisterInstanceAccess"
    AWS_CLOUD_SHELL_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudShellFullAccess"
    CLOUD_TRAIL_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCloudTrail_FullAccess"
    CLOUD_TRAIL_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCloudTrail_ReadOnlyAccess"
    AWS_CLOUD_WATCH_ALARMS_ACTION_SSM_INCIDENTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSCloudWatchAlarms_ActionSSMIncidentsServiceRolePolicy"
    AWS_CODE_ARTIFACT_ADMIN_ACCESS = "arn:aws:iam::aws:policy/AWSCodeArtifactAdminAccess"
    AWS_CODE_ARTIFACT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodeArtifactReadOnlyAccess"
    AWS_CODE_BUILD_ADMIN_ACCESS = "arn:aws:iam::aws:policy/AWSCodeBuildAdminAccess"
    AWS_CODE_BUILD_DEVELOPER_ACCESS = "arn:aws:iam::aws:policy/AWSCodeBuildDeveloperAccess"
    AWS_CODE_BUILD_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodeBuildReadOnlyAccess"
    AWS_CODE_COMMIT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodeCommitFullAccess"
    AWS_CODE_COMMIT_POWER_USER = "arn:aws:iam::aws:policy/AWSCodeCommitPowerUser"
    AWS_CODE_COMMIT_READ_ONLY = "arn:aws:iam::aws:policy/AWSCodeCommitReadOnly"
    AWS_CODE_DEPLOY_DEPLOYER_ACCESS = "arn:aws:iam::aws:policy/AWSCodeDeployDeployerAccess"
    AWS_CODE_DEPLOY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodeDeployFullAccess"
    AWS_CODE_DEPLOY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodeDeployReadOnlyAccess"
    AWS_CODE_DEPLOY_ROLE = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRole"
    AWS_CODE_DEPLOY_ROLE_FOR_CLOUD_FORMATION = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRoleForCloudFormation"
    AWS_CODE_DEPLOY_ROLE_FOR_ECS = "arn:aws:iam::aws:policy/AWSCodeDeployRoleForECS"
    AWS_CODE_DEPLOY_ROLE_FOR_ECS_LIMITED = "arn:aws:iam::aws:policy/AWSCodeDeployRoleForECSLimited"
    AWS_CODE_DEPLOY_ROLE_FOR_LAMBDA = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRoleForLambda"
    AWS_CODE_DEPLOY_ROLE_FOR_LAMBDA_LIMITED = "arn:aws:iam::aws:policy/service-role/AWSCodeDeployRoleForLambdaLimited"
    AWS_CODE_PIPELINE_APPROVER_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineApproverAccess"
    AWS_CODE_PIPELINE_CUSTOM_ACTION_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineCustomActionAccess"
    AWS_CODE_PIPELINE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineFullAccess"
    AWS_CODE_PIPELINE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipelineReadOnlyAccess"
    CODE_PIPELINE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipeline_FullAccess"
    CODE_PIPELINE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSCodePipeline_ReadOnlyAccess"
    AWS_CODE_STAR_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSCodeStarFullAccess"
    AWS_CODE_STAR_NOTIFICATIONS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSCodeStarNotificationsServiceRolePolicy"
    AWS_CODE_STAR_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSCodeStarServiceRole"
    AW_S_CONFIG_ROLE = "arn:aws:iam::aws:policy/service-role/AWS_ConfigRole"
    AWS_CONFIG_ROLE = "arn:aws:iam::aws:policy/service-role/AWSConfigRole"
    AWS_COMPROMISED_KEY_QUARANTINE = "arn:aws:iam::aws:policy/AWSCompromisedKeyQuarantine"
    AWS_COMPROMISED_KEY_QUARANTINE_V2 = "arn:aws:iam::aws:policy/AWSCompromisedKeyQuarantineV2"
    AWS_CONFIG_MULTI_ACCOUNT_SETUP_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSConfigMultiAccountSetupPolicy"
    AWS_CONFIG_REMEDIATION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSConfigRemediationServiceRolePolicy"
    AWS_CONFIG_ROLE_FOR_ORGANIZATIONS = "arn:aws:iam::aws:policy/service-role/AWSConfigRoleForOrganizations"
    AWS_CONFIG_RULES_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSConfigRulesExecutionRole"
    AWS_CONFIG_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSConfigServiceRolePolicy"
    AWS_CONFIG_USER_ACCESS = "arn:aws:iam::aws:policy/AWSConfigUserAccess"
    AWS_CONNECTOR = "arn:aws:iam::aws:policy/AWSConnector"
    AWS_CONTROL_TOWER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSControlTowerServiceRolePolicy"
    AWS_COST_AND_USAGE_REPORT_AUTOMATION_POLICY = "arn:aws:iam::aws:policy/service-role/AWSCostAndUsageReportAutomationPolicy"
    AWS_DATA_EXCHANGE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDataExchangeFullAccess"
    AWS_DATA_EXCHANGE_PROVIDER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDataExchangeProviderFullAccess"
    AWS_DATA_EXCHANGE_READ_ONLY = "arn:aws:iam::aws:policy/AWSDataExchangeReadOnly"
    AWS_DATA_EXCHANGE_SUBSCRIBER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDataExchangeSubscriberFullAccess"
    AWS_DATA_LIFECYCLE_MANAGER_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSDataLifecycleManagerServiceRole"
    AWS_DATA_LIFECYCLE_MANAGER_SERVICE_ROLE_FOR_AMI_MANAGEMENT = "arn:aws:iam::aws:policy/service-role/AWSDataLifecycleManagerServiceRoleForAMIManagement"
    AWS_DATA_PIPELINE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSDataPipelineRole"
    AWS_DATA_PIPELINE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDataPipeline_FullAccess"
    AWS_DATA_PIPELINE_POWER_USER = "arn:aws:iam::aws:policy/AWSDataPipeline_PowerUser"
    AWS_DATA_SYNC_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDataSyncFullAccess"
    AWS_DATA_SYNC_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSDataSyncReadOnlyAccess"
    AWS_DEEP_LENS_LAMBDA_FUNCTION_ACCESS_POLICY = "arn:aws:iam::aws:policy/AWSDeepLensLambdaFunctionAccessPolicy"
    AWS_DEEP_LENS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSDeepLensServiceRolePolicy"
    AWS_DEEP_RACER_ACCOUNT_ADMIN_ACCESS = "arn:aws:iam::aws:policy/AWSDeepRacerAccountAdminAccess"
    AWS_DEEP_RACER_CLOUD_FORMATION_ACCESS_POLICY = "arn:aws:iam::aws:policy/AWSDeepRacerCloudFormationAccessPolicy"
    AWS_DEEP_RACER_DEFAULT_MULTI_USER_ACCESS = "arn:aws:iam::aws:policy/AWSDeepRacerDefaultMultiUserAccess"
    AWS_DEEP_RACER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDeepRacerFullAccess"
    AWS_DEEP_RACER_ROBO_MAKER_ACCESS_POLICY = "arn:aws:iam::aws:policy/AWSDeepRacerRoboMakerAccessPolicy"
    AWS_DEEP_RACER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSDeepRacerServiceRolePolicy"
    AWS_DENY_ALL = "arn:aws:iam::aws:policy/AWSDenyAll"
    AWS_DEVICE_FARM_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDeviceFarmFullAccess"
    AWS_DEVICE_FARM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSDeviceFarmServiceRolePolicy"
    AWS_DEVICE_FARM_TEST_GRID_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSDeviceFarmTestGridServiceRolePolicy"
    AWS_DIRECT_CONNECT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDirectConnectFullAccess"
    AWS_DIRECT_CONNECT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSDirectConnectReadOnlyAccess"
    AWS_DIRECT_CONNECT_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSDirectConnectServiceRolePolicy"
    AWS_DIRECTORY_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSDirectoryServiceFullAccess"
    AWS_DIRECTORY_SERVICE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSDirectoryServiceReadOnlyAccess"
    AWS_DISCOVERY_CONTINUOUS_EXPORT_FIREHOSE_POLICY = "arn:aws:iam::aws:policy/AWSDiscoveryContinuousExportFirehosePolicy"
    AWSEC2_CAPACITY_RESERVATION_FLEET_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2CapacityReservationFleetRolePolicy"
    AWSEC2_FLEET_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2FleetServiceRolePolicy"
    AWSEC2_SPOT_FLEET_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2SpotFleetServiceRolePolicy"
    AWSEC2_SPOT_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSEC2SpotServiceRolePolicy"
    AWSECR_PULL_THROUGH_CACHE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSECRPullThroughCache_ServiceRolePolicy"
    AWS_ELASTIC_BEANSTALK_CUSTOM_PLATFORMFOR_EC2_ROLE = "arn:aws:iam::aws:policy/AWSElasticBeanstalkCustomPlatformforEC2Role"
    AWS_ELASTIC_BEANSTALK_ENHANCED_HEALTH = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkEnhancedHealth"
    AWS_ELASTIC_BEANSTALK_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElasticBeanstalkFullAccess"
    AWS_ELASTIC_BEANSTALK_MAINTENANCE = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticBeanstalkMaintenance"
    AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_CUSTOMER_ROLE_POLICY = "arn:aws:iam::aws:policy/AWSElasticBeanstalkManagedUpdatesCustomerRolePolicy"
    AWS_ELASTIC_BEANSTALK_MANAGED_UPDATES_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticBeanstalkManagedUpdatesServiceRolePolicy"
    AWS_ELASTIC_BEANSTALK_MULTICONTAINER_DOCKER = "arn:aws:iam::aws:policy/AWSElasticBeanstalkMulticontainerDocker"
    AWS_ELASTIC_BEANSTALK_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSElasticBeanstalkReadOnlyAccess"
    AWS_ELASTIC_BEANSTALK_READ_ONLY = "arn:aws:iam::aws:policy/AWSElasticBeanstalkReadOnly"
    AWS_ELASTIC_BEANSTALK_ROLE_CWL = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleCWL"
    AWS_ELASTIC_BEANSTALK_ROLE_CORE = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleCore"
    AWS_ELASTIC_BEANSTALK_ROLE_ECS = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleECS"
    AWS_ELASTIC_BEANSTALK_ROLE_RDS = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleRDS"
    AWS_ELASTIC_BEANSTALK_ROLE_SNS = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleSNS"
    AWS_ELASTIC_BEANSTALK_ROLE_WORKER_TIER = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkRoleWorkerTier"
    AWS_ELASTIC_BEANSTALK_SERVICE = "arn:aws:iam::aws:policy/service-role/AWSElasticBeanstalkService"
    AWS_ELASTIC_BEANSTALK_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticBeanstalkServiceRolePolicy"
    AWS_ELASTIC_BEANSTALK_WEB_TIER = "arn:aws:iam::aws:policy/AWSElasticBeanstalkWebTier"
    AWS_ELASTIC_BEANSTAK_WORKER_TIER = "arn:aws:iam::aws:policy/AWSElasticBeanstalkWorkerTier"
    AWS_ELASTIC_BEANSTALK_WORKER_TIER = "arn:aws:iam::aws:policy/AWSElasticBeanstalkWorkerTier"
    AWS_ELASTIC_DISASTER_RECOVERY_AGENT_INSTALLATION_POLICY = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryAgentInstallationPolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_AGENT_POLICY = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryAgentPolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryConsoleFullAccess"
    AWS_ELASTIC_DISASTER_RECOVERY_CONVERSION_SERVER_POLICY = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryConversionServerPolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_EC2_INSTANCE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryEc2InstancePolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_INSTALLATION_POLICY = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryFailbackInstallationPolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_FAILBACK_POLICY = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryFailbackPolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSElasticDisasterRecoveryReadOnlyAccess"
    AWS_ELASTIC_DISASTER_RECOVERY_RECOVERY_INSTANCE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryRecoveryInstancePolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_REPLICATION_SERVER_POLICY = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryReplicationServerPolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticDisasterRecoveryServiceRolePolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_STAGING_ACCOUNT_POLICY = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryStagingAccountPolicy"
    AWS_ELASTIC_DISASTER_RECOVERY_STAGING_ACCOUNT_POLICY_V2 = "arn:aws:iam::aws:policy/service-role/AWSElasticDisasterRecoveryStagingAccountPolicy_v2"
    AWS_ELASTIC_LOAD_BALANCING_CLASSIC_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticLoadBalancingClassicServiceRolePolicy"
    AWS_ELASTIC_LOAD_BALANCING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSElasticLoadBalancingServiceRolePolicy"
    AWS_ELEMENTAL_MEDIA_CONVERT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElementalMediaConvertFullAccess"
    AWS_ELEMENTAL_MEDIA_CONVERT_READ_ONLY = "arn:aws:iam::aws:policy/AWSElementalMediaConvertReadOnly"
    AWS_ELEMENTAL_MEDIA_LIVE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElementalMediaLiveFullAccess"
    AWS_ELEMENTAL_MEDIA_LIVE_READ_ONLY = "arn:aws:iam::aws:policy/AWSElementalMediaLiveReadOnly"
    AWS_ELEMENTAL_MEDIA_PACKAGE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElementalMediaPackageFullAccess"
    AWS_ELEMENTAL_MEDIA_PACKAGE_READ_ONLY = "arn:aws:iam::aws:policy/AWSElementalMediaPackageReadOnly"
    AWS_ELEMENTAL_MEDIA_STORE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElementalMediaStoreFullAccess"
    AWS_ELEMENTAL_MEDIA_STORE_READ_ONLY = "arn:aws:iam::aws:policy/AWSElementalMediaStoreReadOnly"
    AWS_ELEMENTAL_MEDIA_TAILOR_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSElementalMediaTailorFullAccess"
    AWS_ELEMENTAL_MEDIA_TAILOR_READ_ONLY = "arn:aws:iam::aws:policy/AWSElementalMediaTailorReadOnly"
    AWS_ENHANCED_CLASSIC_NETWORKING_MANGEMENT_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSEnhancedClassicNetworkingMangementPolicy"
    AWSFM_ADMIN_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSFMAdminFullAccess"
    AWSFM_ADMIN_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSFMAdminReadOnlyAccess"
    AWSFM_MEMBER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSFMMemberReadOnlyAccess"
    AWS_FAULT_INJECTION_SIMULATOR_EC2_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSFaultInjectionSimulatorEC2Access"
    AWS_FAULT_INJECTION_SIMULATOR_ECS_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSFaultInjectionSimulatorECSAccess"
    AWS_FAULT_INJECTION_SIMULATOR_EKS_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSFaultInjectionSimulatorEKSAccess"
    AWS_FAULT_INJECTION_SIMULATOR_NETWORK_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSFaultInjectionSimulatorNetworkAccess"
    AWS_FAULT_INJECTION_SIMULATOR_RDS_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSFaultInjectionSimulatorRDSAccess"
    AWS_FAULT_INJECTION_SIMULATOR_SSM_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSFaultInjectionSimulatorSSMAccess"
    AWS_FOR_WORD_PRESS_PLUGIN_POLICY = "arn:aws:iam::aws:policy/AWSForWordPressPluginPolicy"
    AWS_GLOBAL_ACCELERATOR_SLR_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSGlobalAcceleratorSLRPolicy"
    AWS_GLUE_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSGlueConsoleFullAccess"
    AWS_GLUE_CONSOLE_SAGE_MAKER_NOTEBOOK_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSGlueConsoleSageMakerNotebookFullAccess"
    AWS_GLUE_DATA_BREW_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSGlueDataBrewServiceRole"
    AWS_GLUE_SCHEMA_REGISTRY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSGlueSchemaRegistryFullAccess"
    AWS_GLUE_SCHEMA_REGISTRY_READONLY_ACCESS = "arn:aws:iam::aws:policy/AWSGlueSchemaRegistryReadonlyAccess"
    AWS_GLUE_SERVICE_NOTEBOOK_ROLE = "arn:aws:iam::aws:policy/service-role/AWSGlueServiceNotebookRole"
    AWS_GLUE_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSGlueServiceRole"
    AWS_GRAFANA_ACCOUNT_ADMINISTRATOR = "arn:aws:iam::aws:policy/AWSGrafanaAccountAdministrator"
    AWS_GRAFANA_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSGrafanaConsoleReadOnlyAccess"
    AWS_GRAFANA_WORKSPACE_PERMISSION_MANAGEMENT = "arn:aws:iam::aws:policy/AWSGrafanaWorkspacePermissionManagement"
    AWS_GREENGRASS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSGreengrassFullAccess"
    AWS_GREENGRASS_FULLCCESS = "arn:aws:iam::aws:policy/AWSGreengrassFullAccess"
    AWS_GREENGRASS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSGreengrassReadOnlyAccess"
    AWS_GREENGRASS_RESOURCE_ACCESS_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSGreengrassResourceAccessRolePolicy"
    AWS_HEALTH_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSHealthFullAccess"
    AWS_HEALTH_EVENT_PROCESSOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSHealth_EventProcessorServiceRolePolicy"
    AWSIPAM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSIPAMServiceRolePolicy"
    AWSIQ_CONTRACT_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSIQContractServiceRolePolicy"
    AWSIQ_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIQFullAccess"
    AWSIQ_PERMISSION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSIQPermissionServiceRolePolicy"
    AWS_IDENTITY_SYNC_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIdentitySyncFullAccess"
    AWS_IDENTITY_SYNC_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIdentitySyncReadOnlyAccess"
    AWS_IMAGE_BUILDER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSImageBuilderFullAccess"
    AWS_IMAGE_BUILDER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSImageBuilderReadOnlyAccess"
    AWS_IMPORT_EXPORT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSImportExportFullAccess"
    AWS_IMPORT_EXPORT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSImportExportReadOnlyAccess"
    AWS_INCIDENT_MANAGER_RESOLVER_ACCESS = "arn:aws:iam::aws:policy/AWSIncidentManagerResolverAccess"
    AWS_INCIDENT_MANAGER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSIncidentManagerServiceRolePolicy"
    AWS_IO_T1_CLICK_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoT1ClickFullAccess"
    AWS_IO_T1_CLICK_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIoT1ClickReadOnlyAccess"
    AWS_IO_T_ANALYTICS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTAnalyticsFullAccess"
    AWS_IO_T_ANALYTICS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIoTAnalyticsReadOnlyAccess"
    AWS_IO_T_CONFIG_ACCESS = "arn:aws:iam::aws:policy/AWSIoTConfigAccess"
    AWS_IO_T_CONFIG_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIoTConfigReadOnlyAccess"
    AWS_IO_T_DATA_ACCESS = "arn:aws:iam::aws:policy/AWSIoTDataAccess"
    AWS_IO_T_DEVICE_DEFENDER_ADD_THINGS_TO_THING_GROUP_MITIGATION_ACTION = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderAddThingsToThingGroupMitigationAction"
    AWS_IO_T_DEVICE_DEFENDER_AUDIT = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderAudit"
    AWS_IO_T_DEVICE_DEFENDER_ENABLE_IO_T_LOGGING_MITIGATION_ACTION = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderEnableIoTLoggingMitigationAction"
    AWS_IO_T_DEVICE_DEFENDER_PUBLISH_FINDINGS_TO_SNS_MITIGATION_ACTION = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderPublishFindingsToSNSMitigationAction"
    AWS_IO_T_DEVICE_DEFENDER_REPLACE_DEFAULT_POLICY_MITIGATION_ACTION = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderReplaceDefaultPolicyMitigationAction"
    AWS_IO_T_DEVICE_DEFENDER_UPDATE_CA_CERT_MITIGATION_ACTION = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderUpdateCACertMitigationAction"
    AWS_IO_T_DEVICE_DEFENDER_UPDATE_DEVICE_CERT_MITIGATION_ACTION = "arn:aws:iam::aws:policy/service-role/AWSIoTDeviceDefenderUpdateDeviceCertMitigationAction"
    AWS_IO_T_DEVICE_TESTER_FOR_FREE_RTOS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTDeviceTesterForFreeRTOSFullAccess"
    AWS_IO_T_DEVICE_TESTER_FOR_GREENGRASS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTDeviceTesterForGreengrassFullAccess"
    AWS_IO_T_EVENTS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTEventsFullAccess"
    AWS_IO_T_EVENTS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIoTEventsReadOnlyAccess"
    AWS_IO_T_FLEET_HUB_FEDERATION_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSIoTFleetHubFederationAccess"
    AWS_IO_T_FLEETWISE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSIoTFleetwiseServiceRolePolicy"
    AWS_IO_T_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTFullAccess"
    AWS_IO_T_LOGGING = "arn:aws:iam::aws:policy/service-role/AWSIoTLogging"
    AWS_IO_TOTA_UPDATE = "arn:aws:iam::aws:policy/service-role/AWSIoTOTAUpdate"
    AWS_IO_T_RULE_ACTIONS = "arn:aws:iam::aws:policy/service-role/AWSIoTRuleActions"
    AWS_IO_T_SITE_WISE_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTSiteWiseConsoleFullAccess"
    AWS_IO_T_SITE_WISE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTSiteWiseFullAccess"
    AWS_IO_T_SITE_WISE_MONITOR_PORTAL_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSIoTSiteWiseMonitorPortalAccess"
    AWS_IO_T_SITE_WISE_MONITOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSIoTSiteWiseMonitorServiceRolePolicy"
    AWS_IO_T_SITE_WISE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIoTSiteWiseReadOnlyAccess"
    AWS_IO_T_THINGS_REGISTRATION = "arn:aws:iam::aws:policy/service-role/AWSIoTThingsRegistration"
    AWS_IO_T_WIRELESS_DATA_ACCESS = "arn:aws:iam::aws:policy/AWSIoTWirelessDataAccess"
    AWS_IO_T_WIRELESS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIoTWirelessFullAccess"
    AWS_IO_T_WIRELESS_FULL_PUBLISH_ACCESS = "arn:aws:iam::aws:policy/AWSIoTWirelessFullPublishAccess"
    AWS_IO_T_WIRELESS_GATEWAY_CERT_MANAGER = "arn:aws:iam::aws:policy/AWSIoTWirelessGatewayCertManager"
    AWS_IO_T_WIRELESS_LOGGING = "arn:aws:iam::aws:policy/AWSIoTWirelessLogging"
    AWS_IO_T_WIRELESS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSIoTWirelessReadOnlyAccess"
    AWS_IOT_ROBO_RUNNER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSIotRoboRunnerFullAccess"
    AWS_IOT_ROBO_RUNNER_READ_ONLY = "arn:aws:iam::aws:policy/AWSIotRoboRunnerReadOnly"
    AWS_IOT_ROBO_RUNNER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSIotRoboRunnerServiceRolePolicy"
    AWS_KEY_MANAGEMENT_SERVICE_CUSTOM_KEY_STORES_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSKeyManagementServiceCustomKeyStoresServiceRolePolicy"
    AWS_KEY_MANAGEMENT_SERVICE_MULTI_REGION_KEYS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSKeyManagementServiceMultiRegionKeysServiceRolePolicy"
    AWS_KEY_MANAGEMENT_SERVICE_POWER_USER = "arn:aws:iam::aws:policy/AWSKeyManagementServicePowerUser"
    AWS_LAKE_FORMATION_CROSS_ACCOUNT_MANAGER = "arn:aws:iam::aws:policy/AWSLakeFormationCrossAccountManager"
    AWS_LAKE_FORMATION_DATA_ADMIN = "arn:aws:iam::aws:policy/AWSLakeFormationDataAdmin"
    AWS_LAMBDA_BASIC_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaBasicExecutionRole"
    AWS_LAMBDA_DYNAMO_DB_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaDynamoDBExecutionRole"
    AWS_LAMBDA_ENI_MANAGEMENT_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSLambdaENIManagementAccess"
    AWS_LAMBDA_EXECUTE = "arn:aws:iam::aws:policy/AWSLambdaExecute"
    AWS_LAMBDA_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSLambdaFullAccess"
    LAMBDA_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSLambda_FullAccess"
    AWS_LAMBDA_INVOCATION_DYNAMO_DB = "arn:aws:iam::aws:policy/AWSLambdaInvocation-DynamoDB"
    AWS_LAMBDA_KINESIS_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaKinesisExecutionRole"
    AWS_LAMBDA_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSLambdaReadOnlyAccess"
    LAMBDA_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSLambda_ReadOnlyAccess"
    AWS_LAMBDA_MSK_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaMSKExecutionRole"
    AWS_LAMBDA_REPLICATOR = "arn:aws:iam::aws:policy/aws-service-role/AWSLambdaReplicator"
    AWS_LAMBDA_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaRole"
    AWS_LAMBDA_SQS_QUEUE_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaSQSQueueExecutionRole"
    AWS_LAMBDA_VPC_ACCESS_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AWSLambdaVPCAccessExecutionRole"
    AWS_LICENSE_MANAGER_CONSUMPTION_POLICY = "arn:aws:iam::aws:policy/service-role/AWSLicenseManagerConsumptionPolicy"
    AWS_LICENSE_MANAGER_LINUX_SUBSCRIPTIONS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerLinuxSubscriptionsServiceRolePolicy"
    AWS_LICENSE_MANAGER_MASTER_ACCOUNT_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerMasterAccountRolePolicy"
    AWS_LICENSE_MANAGER_MEMBER_ACCOUNT_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerMemberAccountRolePolicy"
    AWS_LICENSE_MANAGER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerServiceRolePolicy"
    AWS_LICENSE_MANAGER_USER_SUBSCRIPTIONS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSLicenseManagerUserSubscriptionsServiceRolePolicy"
    AWSM2_SERVICE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSM2ServicePolicy"
    AWS_MANAGED_SERVICES_DEPLOYMENT_TOOLKIT_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSManagedServicesDeploymentToolkitPolicy"
    AWS_MANAGED_SERVICES_DETECTIVE_CONTROLS_CONFIG_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSManagedServices_DetectiveControlsConfig_ServiceRolePolicy"
    AWS_MANAGED_SERVICES_EVENTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSManagedServices_EventsServiceRolePolicy"
    AWS_MARKETPLACE_AMI_INGESTION = "arn:aws:iam::aws:policy/AWSMarketplaceAmiIngestion"
    AWS_MARKETPLACE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceFullAccess"
    AWS_MARKETPLACE_GET_ENTITLEMENTS = "arn:aws:iam::aws:policy/AWSMarketplaceGetEntitlements"
    AWS_MARKETPLACE_IMAGE_BUILD_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceImageBuildFullAccess"
    AWS_MARKETPLACE_LICENSE_MANAGEMENT_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSMarketplaceLicenseManagementServiceRolePolicy"
    AWS_MARKETPLACE_MANAGE_SUBSCRIPTIONS = "arn:aws:iam::aws:policy/AWSMarketplaceManageSubscriptions"
    AWS_MARKETPLACE_METERING_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceMeteringFullAccess"
    AWS_MARKETPLACE_METERING_REGISTER_USAGE = "arn:aws:iam::aws:policy/AWSMarketplaceMeteringRegisterUsage"
    AWS_MARKETPLACE_PROCUREMENT_SYSTEM_ADMIN_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceProcurementSystemAdminFullAccess"
    AWS_MARKETPLACE_PURCHASE_ORDERS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSMarketplacePurchaseOrdersServiceRolePolicy"
    AWS_MARKETPLACE_READONLY = "arn:aws:iam::aws:policy/AWSMarketplaceRead-only"
    AWS_MARKETPLACE_SELLER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceSellerFullAccess"
    AWS_MARKETPLACE_SELLER_PRODUCTS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMarketplaceSellerProductsFullAccess"
    AWS_MARKETPLACE_SELLER_PRODUCTS_READ_ONLY = "arn:aws:iam::aws:policy/AWSMarketplaceSellerProductsReadOnly"
    AWS_MEDIA_TAILOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSMediaTailorServiceRolePolicy"
    AWS_MIGRATION_HUB_DMS_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSMigrationHubDMSAccess"
    AWS_MIGRATION_HUB_DISCOVERY_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSMigrationHubDiscoveryAccess"
    AWS_MIGRATION_HUB_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMigrationHubFullAccess"
    AWS_MIGRATION_HUB_ORCHESTRATOR_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMigrationHubOrchestratorConsoleFullAccess"
    AWS_MIGRATION_HUB_ORCHESTRATOR_INSTANCE_ROLE_POLICY = "arn:aws:iam::aws:policy/AWSMigrationHubOrchestratorInstanceRolePolicy"
    AWS_MIGRATION_HUB_ORCHESTRATOR_PLUGIN = "arn:aws:iam::aws:policy/AWSMigrationHubOrchestratorPlugin"
    AWS_MIGRATION_HUB_ORCHESTRATOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSMigrationHubOrchestratorServiceRolePolicy"
    AWS_MIGRATION_HUB_REFACTOR_SPACES_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMigrationHubRefactorSpacesFullAccess"
    AWS_MIGRATION_HUB_REFACTOR_SPACES_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSMigrationHubRefactorSpacesServiceRolePolicy"
    AWS_MIGRATION_HUB_SMS_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSMigrationHubSMSAccess"
    AWS_MIGRATION_HUB_STRATEGY_COLLECTOR = "arn:aws:iam::aws:policy/AWSMigrationHubStrategyCollector"
    AWS_MIGRATION_HUB_STRATEGY_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMigrationHubStrategyConsoleFullAccess"
    AWS_MIGRATION_HUB_STRATEGY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSMigrationHubStrategyServiceRolePolicy"
    AWS_MOBILE_HUB_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSMobileHub_FullAccess"
    AWS_MOBILE_HUB_READ_ONLY = "arn:aws:iam::aws:policy/AWSMobileHub_ReadOnly"
    AWS_MOBILE_HUB_SERVICE_USE_ONLY = "arn:aws:iam::aws:policy/service-role/AWSMobileHub_ServiceUseOnly"
    AWS_NETWORK_FIREWALL_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSNetworkFirewallServiceRolePolicy"
    AWS_NETWORK_MANAGER_CLOUD_WAN_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSNetworkManagerCloudWANServiceRolePolicy"
    AWS_NETWORK_MANAGER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSNetworkManagerFullAccess"
    AWS_NETWORK_MANAGER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSNetworkManagerReadOnlyAccess"
    AWS_NETWORK_MANAGER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSNetworkManagerServiceRolePolicy"
    AWS_OPS_WORKS_CM_INSTANCE_PROFILE_ROLE = "arn:aws:iam::aws:policy/AWSOpsWorksCMInstanceProfileRole"
    AWS_OPS_WORKS_CM_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AWSOpsWorksCMServiceRole"
    AWS_OPS_WORKS_CLOUD_WATCH_LOGS = "arn:aws:iam::aws:policy/AWSOpsWorksCloudWatchLogs"
    AWS_OPS_WORKS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSOpsWorksFullAccess"
    AWS_OPS_WORKS_INSTANCE_REGISTRATION = "arn:aws:iam::aws:policy/AWSOpsWorksInstanceRegistration"
    AWS_OPS_WORKS_REGISTER_CLI = "arn:aws:iam::aws:policy/AWSOpsWorksRegisterCLI"
    AWS_OPS_WORKS_ROLE = "arn:aws:iam::aws:policy/service-role/AWSOpsWorksRole"
    AWS_QUICK_SIGHT_DESCRIBE_RD = "arn:aws:iam::aws:policy/service-role/AWSQuickSightDescribeRDS"
    AWS_OPS_WORKS_REGISTER_CL_I_EC2 = "arn:aws:iam::aws:policy/AWSOpsWorksRegisterCLI_EC2"
    AWS_OPS_WORKS_REGISTER_CL_I_ON_PREMISES = "arn:aws:iam::aws:policy/AWSOpsWorksRegisterCLI_OnPremises"
    OPS_WORKS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSOpsWorks_FullAccess"
    AWS_ORGANIZATIONS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSOrganizationsFullAccess"
    AWS_ORGANIZATIONS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSOrganizationsReadOnlyAccess"
    AWS_ORGANIZATIONS_SERVICE_TRUST_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSOrganizationsServiceTrustPolicy"
    AWS_OUTPOSTS_AUTHORIZE_SERVER_POLICY = "arn:aws:iam::aws:policy/AWSOutpostsAuthorizeServerPolicy"
    AWS_OUTPOSTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSOutpostsServiceRolePolicy"
    AWS_PANORAMA_APPLIANCE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSPanoramaApplianceRolePolicy"
    AWS_PANORAMA_APPLIANCE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSPanoramaApplianceServiceRolePolicy"
    AWS_PANORAMA_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSPanoramaFullAccess"
    AWS_PANORAMA_GREENGRASS_GROUP_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSPanoramaGreengrassGroupRolePolicy"
    AWS_PANORAMA_SAGE_MAKER_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSPanoramaSageMakerRolePolicy"
    AWS_PANORAMA_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSPanoramaServiceLinkedRolePolicy"
    AWS_PANORAMA_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AWSPanoramaServiceRolePolicy"
    AWS_PRICE_LIST_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSPriceListServiceFullAccess"
    AWS_PRIVATE_CA_AUDITOR = "arn:aws:iam::aws:policy/AWSPrivateCAAuditor"
    AWS_PRIVATE_CA_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSPrivateCAFullAccess"
    AWS_PRIVATE_CA_PRIVILEGED_USER = "arn:aws:iam::aws:policy/AWSPrivateCAPrivilegedUser"
    AWS_PRIVATE_CA_READ_ONLY = "arn:aws:iam::aws:policy/AWSPrivateCAReadOnly"
    AWS_PRIVATE_CAUSER = "arn:aws:iam::aws:policy/AWSPrivateCAUser"
    AWS_PRIVATE_MARKETPLACE_ADMIN_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSPrivateMarketplaceAdminFullAccess"
    AWS_PRIVATE_MARKETPLACE_REQUESTS = "arn:aws:iam::aws:policy/AWSPrivateMarketplaceRequests"
    AWS_PRIVATE_NETWORKS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSPrivateNetworksServiceRolePolicy"
    AWS_PROTON_CODE_BUILD_PROVISIONING_BASIC_ACCESS = "arn:aws:iam::aws:policy/AWSProtonCodeBuildProvisioningBasicAccess"
    AWS_PROTON_CODE_BUILD_PROVISIONING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSProtonCodeBuildProvisioningServiceRolePolicy"
    AWS_PROTON_DEVELOPER_ACCESS = "arn:aws:iam::aws:policy/AWSProtonDeveloperAccess"
    AWS_PROTON_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSProtonFullAccess"
    AWS_PROTON_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSProtonReadOnlyAccess"
    AWS_PROTON_SYNC_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSProtonSyncServiceRolePolicy"
    AWS_PURCHASE_ORDERS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/AWSPurchaseOrdersServiceRolePolicy"
    AWS_QUICK_SIGHT_DESCRIBE_RDS = "arn:aws:iam::aws:policy/service-role/AWSQuickSightDescribeRDS"
    AWS_QUICK_SIGHT_DESCRIBE_REDSHIFT = "arn:aws:iam::aws:policy/service-role/AWSQuickSightDescribeRedshift"
    AWS_QUICK_SIGHT_ELASTICSEARCH_POLICY = "arn:aws:iam::aws:policy/service-role/AWSQuickSightElasticsearchPolicy"
    AWS_QUICK_SIGHT_IO_T_ANALYTICS_ACCESS = "arn:aws:iam::aws:policy/AWSQuickSightIoTAnalyticsAccess"
    AWS_QUICK_SIGHT_LIST_IAM = "arn:aws:iam::aws:policy/service-role/AWSQuickSightListIAM"
    AWS_QUICK_SIGHT_SAGE_MAKER_POLICY = "arn:aws:iam::aws:policy/service-role/AWSQuickSightSageMakerPolicy"
    AWS_QUICK_SIGHT_TIMESTREAM_POLICY = "arn:aws:iam::aws:policy/service-role/AWSQuickSightTimestreamPolicy"
    AWS_QUICKSIGHT_ATHENA_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSQuicksightAthenaAccess"
    AWS_QUICKSIGHT_OPEN_SEARCH_POLICY = "arn:aws:iam::aws:policy/service-role/AWSQuicksightOpenSearchPolicy"
    AWS_REACHABILITY_ANALYZER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSReachabilityAnalyzerServiceRolePolicy"
    AWS_REFACTORING_TOOLKIT_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSRefactoringToolkitFullAccess"
    AWS_REFACTORING_TOOLKIT_SIDECAR_POLICY = "arn:aws:iam::aws:policy/AWSRefactoringToolkitSidecarPolicy"
    AWS_RESOURCE_ACCESS_MANAGER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSResourceAccessManagerFullAccess"
    AWS_RESOURCE_ACCESS_MANAGER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSResourceAccessManagerReadOnlyAccess"
    AWS_RESOURCE_ACCESS_MANAGER_RESOURCE_SHARE_PARTICIPANT_ACCESS = "arn:aws:iam::aws:policy/AWSResourceAccessManagerResourceShareParticipantAccess"
    AWS_RESOURCE_ACCESS_MANAGER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSResourceAccessManagerServiceRolePolicy"
    AWS_RESOURCE_EXPLORER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSResourceExplorerFullAccess"
    AWS_RESOURCE_EXPLORER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSResourceExplorerReadOnlyAccess"
    AWS_RESOURCE_EXPLORER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSResourceExplorerServiceRolePolicy"
    AWS_RESOURCE_GROUPS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSResourceGroupsReadOnlyAccess"
    AWS_ROBO_MAKER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSRoboMakerReadOnlyAccess"
    AWS_ROBO_MAKER_SERVICE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSRoboMakerServicePolicy"
    AWS_ROBO_MAKER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/AWSRoboMakerServiceRolePolicy"
    AWS_ROBO_MAKER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSRoboMaker_FullAccess"
    AWS_ROLES_ANYWHERE_SERVICE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSRolesAnywhereServicePolicy"
    AWSSSM_FOR_SAP_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSSMForSAPServiceLinkedRolePolicy"
    AWSSSM_OPS_INSIGHTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSSMOpsInsightsServiceRolePolicy"
    AWSSSO_DIRECTORY_ADMINISTRATOR = "arn:aws:iam::aws:policy/AWSSSODirectoryAdministrator"
    AWSSSO_DIRECTORY_READ_ONLY = "arn:aws:iam::aws:policy/AWSSSODirectoryReadOnly"
    AWSSSO_MASTER_ACCOUNT_ADMINISTRATOR = "arn:aws:iam::aws:policy/AWSSSOMasterAccountAdministrator"
    AWSSSO_MEMBER_ACCOUNT_ADMINISTRATOR = "arn:aws:iam::aws:policy/AWSSSOMemberAccountAdministrator"
    AWSSSO_READ_ONLY = "arn:aws:iam::aws:policy/AWSSSOReadOnly"
    AWSSSO_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSSOServiceRolePolicy"
    AWS_SAVINGS_PLANS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSSavingsPlansFullAccess"
    AWS_SAVINGS_PLANS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSSavingsPlansReadOnlyAccess"
    AWS_SECURITY_HUB_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSSecurityHubFullAccess"
    AWS_SECURITY_HUB_ORGANIZATIONS_ACCESS = "arn:aws:iam::aws:policy/AWSSecurityHubOrganizationsAccess"
    AWS_SECURITY_HUB_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSSecurityHubReadOnlyAccess"
    AWS_SECURITY_HUB_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSecurityHubServiceRolePolicy"
    AWS_SERVICE_CATALOG_ADMIN_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSServiceCatalogAdminFullAccess"
    AWS_SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSServiceCatalogAdminReadOnlyAccess"
    AWS_SERVICE_CATALOG_APP_REGISTRY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSServiceCatalogAppRegistryFullAccess"
    AWS_SERVICE_CATALOG_APP_REGISTRY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSServiceCatalogAppRegistryReadOnlyAccess"
    AWS_SERVICE_CATALOG_APP_REGISTRY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceCatalogAppRegistryServiceRolePolicy"
    AWS_SERVICE_CATALOG_END_USER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSServiceCatalogEndUserFullAccess"
    AWS_SERVICE_CATALOG_END_USER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSServiceCatalogEndUserReadOnlyAccess"
    AWS_SERVICE_CATALOG_SYNC_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceCatalogSyncServiceRolePolicy"
    AWS_SERVICE_ROLE_FOR_AMAZON_EKS_NODEGROUP = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForAmazonEKSNodegroup"
    AWS_SERVICE_ROLE_FOR_CLOUD_WATCH_ALARMS_ACTION_SSM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForCloudWatchAlarmsActionSSMServiceRolePolicy"
    AWS_SERVICE_ROLE_FOR_CODE_GURU_PROFILER = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForCodeGuru-Profiler"
    AWS_SERVICE_ROLE_FOR_EC2_SCHEDULED_INSTANCES = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForEC2ScheduledInstances"
    AWS_SERVICE_ROLE_FOR_GROUND_STATION_DATAFLOW_ENDPOINT_GROUP_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForGroundStationDataflowEndpointGroupPolicy"
    AWS_SERVICE_ROLE_FOR_IMAGE_BUILDER = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForImageBuilder"
    AWS_SERVICE_ROLE_FOR_IO_T_SITE_WISE = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForIoTSiteWise"
    AWS_SERVICE_ROLE_FOR_LOG_DELIVERY_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForLogDeliveryPolicy"
    AWS_SERVICE_ROLE_FOR_MONITRON_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForMonitronPolicy"
    AWS_SERVICE_ROLE_FOR_SMS = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRoleForSMS"
    AWS_SERVICE_ROLE_POLICY_FOR_BACKUP_REPORTS = "arn:aws:iam::aws:policy/aws-service-role/AWSServiceRolePolicyForBackupReports"
    AWS_SHIELD_DRT_ACCESS_POLICY = "arn:aws:iam::aws:policy/service-role/AWSShieldDRTAccessPolicy"
    AWS_SHIELD_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSShieldServiceRolePolicy"
    AWS_STEP_FUNCTIONS_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSStepFunctionsConsoleFullAccess"
    AWS_STEP_FUNCTIONS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSStepFunctionsFullAccess"
    AWS_STEP_FUNCTIONS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSStepFunctionsReadOnlyAccess"
    AWS_STORAGE_GATEWAY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSStorageGatewayFullAccess"
    AWS_STORAGE_GATEWAY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSStorageGatewayReadOnlyAccess"
    AWS_STORAGE_GATEWAY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSStorageGatewayServiceRolePolicy"
    AWS_SUPPORT_ACCESS = "arn:aws:iam::aws:policy/AWSSupportAccess"
    AWS_SUPPORT_APP_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSSupportAppFullAccess"
    AWS_SUPPORT_APP_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSSupportAppReadOnlyAccess"
    AWS_SUPPORT_PLANS_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSSupportPlansFullAccess"
    AWS_SUPPORT_PLANS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSSupportPlansReadOnlyAccess"
    AWS_SUPPORT_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSupportServiceRolePolicy"
    AWS_SYSTEMS_MANAGER_ACCOUNT_DISCOVERY_SERVICE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSystemsManagerAccountDiscoveryServicePolicy"
    AWS_SYSTEMS_MANAGER_CHANGE_MANAGEMENT_SERVICE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSystemsManagerChangeManagementServicePolicy"
    AWS_SYSTEMS_MANAGER_FOR_SAP_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSSystemsManagerForSAPFullAccess"
    AWS_SYSTEMS_MANAGER_FOR_SAP_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSSystemsManagerForSAPReadOnlyAccess"
    AWS_SYSTEMS_MANAGER_OPS_DATA_SYNC_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSSystemsManagerOpsDataSyncServiceRolePolicy"
    AWS_THINKBOX_AWS_PORTAL_ADMIN_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxAWSPortalAdminPolicy"
    AWS_THINKBOX_AWS_PORTAL_GATEWAY_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxAWSPortalGatewayPolicy"
    AWS_THINKBOX_AWS_PORTAL_WORKER_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxAWSPortalWorkerPolicy"
    AWS_THINKBOX_ASSET_SERVER_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxAssetServerPolicy"
    AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ACCESS_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineResourceTrackerAccessPolicy"
    AWS_THINKBOX_DEADLINE_RESOURCE_TRACKER_ADMIN_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineResourceTrackerAdminPolicy"
    AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_ADMIN_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineSpotEventPluginAdminPolicy"
    AWS_THINKBOX_DEADLINE_SPOT_EVENT_PLUGIN_WORKER_POLICY = "arn:aws:iam::aws:policy/AWSThinkboxDeadlineSpotEventPluginWorkerPolicy"
    AWS_TRANSFER_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSTransferConsoleFullAccess"
    AWS_TRANSFER_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSTransferFullAccess"
    AWS_TRANSFER_LOGGING_ACCESS = "arn:aws:iam::aws:policy/service-role/AWSTransferLoggingAccess"
    AWS_TRANSFER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSTransferReadOnlyAccess"
    AWS_TRUSTED_ADVISOR_PRIORITY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSTrustedAdvisorPriorityFullAccess"
    AWS_TRUSTED_ADVISOR_PRIORITY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSTrustedAdvisorPriorityReadOnlyAccess"
    AWS_TRUSTED_ADVISOR_REPORTING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSTrustedAdvisorReportingServiceRolePolicy"
    AWS_TRUSTED_ADVISOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSTrustedAdvisorServiceRolePolicy"
    AWSVPCS2_S_VPN_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSVPCS2SVpnServiceRolePolicy"
    AWSVPC_TRANSIT_GATEWAY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSVPCTransitGatewayServiceRolePolicy"
    AWSVPC_VERIFIED_ACCESS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSVPCVerifiedAccessServiceRolePolicy"
    AWS_VENDOR_INSIGHTS_ASSESSOR_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSVendorInsightsAssessorFullAccess"
    AWS_VENDOR_INSIGHTS_ASSESSOR_READ_ONLY = "arn:aws:iam::aws:policy/AWSVendorInsightsAssessorReadOnly"
    AWS_VENDOR_INSIGHTS_VENDOR_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSVendorInsightsVendorFullAccess"
    AWS_VENDOR_INSIGHTS_VENDOR_READ_ONLY = "arn:aws:iam::aws:policy/AWSVendorInsightsVendorReadOnly"
    AWS_VPC_LATTICE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSVpcLatticeServiceRolePolicy"
    AWSWAF_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSWAFConsoleFullAccess"
    AWSWAF_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSWAFConsoleReadOnlyAccess"
    AWSWAF_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSWAFFullAccess"
    AWSWAF_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSWAFReadOnlyAccess"
    AWS_WELL_ARCHITECTED_ORGANIZATIONS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AWSWellArchitectedOrganizationsServiceRolePolicy"
    AWS_WICKR_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSWickrFullAccess"
    AWS_XRAY_CROSS_ACCOUNT_SHARING_CONFIGURATION = "arn:aws:iam::aws:policy/AWSXrayCrossAccountSharingConfiguration"
    AWS_XRAY_FULL_ACCESS = "arn:aws:iam::aws:policy/AWSXrayFullAccess"
    AWS_XRAY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSXrayReadOnlyAccess"
    AWS_XRAY_WRITE_ONLY_ACCESS = "arn:aws:iam::aws:policy/AWSXrayWriteOnlyAccess"
    AWSX_RAY_DAEMON_WRITE_ACCESS = "arn:aws:iam::aws:policy/AWSXRayDaemonWriteAccess"
    ACCESS_ANALYZER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AccessAnalyzerServiceRolePolicy"
    ADMINISTRATOR_ACCESS = "arn:aws:iam::aws:policy/AdministratorAccess"
    ADMINISTRATOR_ACCESS_AWS_ELASTIC_BEANSTALK = "arn:aws:iam::aws:policy/AdministratorAccess-AWSElasticBeanstalk"
    ADMINISTRATOR_ACCESS_AMPLIFY = "arn:aws:iam::aws:policy/AdministratorAccess-Amplify"
    ALEXA_FOR_BUSINESS_DEVICE_SETUP = "arn:aws:iam::aws:policy/AlexaForBusinessDeviceSetup"
    ALEXA_FOR_BUSINESS_FULL_ACCESS = "arn:aws:iam::aws:policy/AlexaForBusinessFullAccess"
    ALEXA_FOR_BUSINESS_GATEWAY_EXECUTION = "arn:aws:iam::aws:policy/AlexaForBusinessGatewayExecution"
    ALEXA_FOR_BUSINESS_LIFESIZE_DELEGATED_ACCESS_POLICY = "arn:aws:iam::aws:policy/AlexaForBusinessLifesizeDelegatedAccessPolicy"
    ALEXA_FOR_BUSINESS_NETWORK_PROFILE_SERVICE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AlexaForBusinessNetworkProfileServicePolicy"
    ALEXA_FOR_BUSINESS_POLY_DELEGATED_ACCESS_POLICY = "arn:aws:iam::aws:policy/AlexaForBusinessPolyDelegatedAccessPolicy"
    ALEXA_FOR_BUSINESS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AlexaForBusinessReadOnlyAccess"
    AMAZON_API_GATEWAY_ADMINISTRATOR = "arn:aws:iam::aws:policy/AmazonAPIGatewayAdministrator"
    AMAZON_API_GATEWAY_INVOKE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAPIGatewayInvokeFullAccess"
    AMAZON_API_GATEWAY_PUSH_TO_CLOUD_WATCH_LOGS = "arn:aws:iam::aws:policy/service-role/AmazonAPIGatewayPushToCloudWatchLogs"
    AMAZON_APP_FLOW_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAppFlowFullAccess"
    AMAZON_APP_FLOW_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonAppFlowReadOnlyAccess"
    AMAZON_APP_STREAM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAppStreamFullAccess"
    AMAZON_APP_STREAM_PCA_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonAppStreamPCAAccess"
    AMAZON_APP_STREAM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonAppStreamReadOnlyAccess"
    AMAZON_APP_STREAM_SERVICE_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonAppStreamServiceAccess"
    AMAZON_ATHENA_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAthenaFullAccess"
    AMAZON_AUGMENTED_AI_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAugmentedAIFullAccess"
    AMAZON_AUGMENTED_AI_HUMAN_LOOP_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonAugmentedAIHumanLoopFullAccess"
    AMAZON_AUGMENTED_AI_INTEGRATED_API_ACCESS = "arn:aws:iam::aws:policy/AmazonAugmentedAIIntegratedAPIAccess"
    AMAZON_BRAKET_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonBraketFullAccess"
    AMAZON_BRAKET_JOBS_EXECUTION_POLICY = "arn:aws:iam::aws:policy/AmazonBraketJobsExecutionPolicy"
    AMAZON_BRAKET_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonBraketServiceRolePolicy"
    AMAZON_CHIME_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonChimeFullAccess"
    AMAZON_CHIME_READ_ONLY = "arn:aws:iam::aws:policy/AmazonChimeReadOnly"
    AMAZON_CHIME_SDK = "arn:aws:iam::aws:policy/AmazonChimeSDK"
    AMAZON_CHIME_SDK_MEDIA_PIPELINES_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonChimeSDKMediaPipelinesServiceLinkedRolePolicy"
    AMAZON_CHIME_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonChimeServiceRolePolicy"
    AMAZON_CHIME_TRANSCRIPTION_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonChimeTranscriptionServiceLinkedRolePolicy"
    AMAZON_CHIME_USER_MANAGEMENT = "arn:aws:iam::aws:policy/AmazonChimeUserManagement"
    AMAZON_CHIME_VOICE_CONNECTOR_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonChimeVoiceConnectorServiceLinkedRolePolicy"
    AMAZON_CLOUD_DIRECTORY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudDirectoryFullAccess"
    AMAZON_CLOUD_DIRECTORY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudDirectoryReadOnlyAccess"
    AMAZON_CLOUD_WATCH_EVIDENTLY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudWatchEvidentlyFullAccess"
    AMAZON_CLOUD_WATCH_EVIDENTLY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudWatchEvidentlyReadOnlyAccess"
    AMAZON_CLOUD_WATCH_EVIDENTLY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonCloudWatchEvidentlyServiceRolePolicy"
    AMAZON_CLOUD_WATCH_RUM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudWatchRUMFullAccess"
    AMAZON_CLOUD_WATCH_RUM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonCloudWatchRUMReadOnlyAccess"
    AMAZON_CLOUD_WATCH_RUM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonCloudWatchRUMServiceRolePolicy"
    AMAZON_CODE_GURU_PROFILER_AGENT_ACCESS = "arn:aws:iam::aws:policy/AmazonCodeGuruProfilerAgentAccess"
    AMAZON_CODE_GURU_PROFILER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonCodeGuruProfilerFullAccess"
    AMAZON_CODE_GURU_PROFILER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonCodeGuruProfilerReadOnlyAccess"
    AMAZON_CODE_GURU_REVIEWER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonCodeGuruReviewerFullAccess"
    AMAZON_CODE_GURU_REVIEWER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonCodeGuruReviewerReadOnlyAccess"
    AMAZON_CODE_GURU_REVIEWER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonCodeGuruReviewerServiceRolePolicy"
    AMAZON_COGNITO_DEVELOPER_AUTHENTICATED_IDENTITIES = "arn:aws:iam::aws:policy/AmazonCognitoDeveloperAuthenticatedIdentities"
    AMAZON_COGNITO_IDP_EMAIL_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonCognitoIdpEmailServiceRolePolicy"
    AMAZON_COGNITO_IDP_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonCognitoIdpServiceRolePolicy"
    AMAZON_COGNITO_POWER_USER = "arn:aws:iam::aws:policy/AmazonCognitoPowerUser"
    AMAZON_COGNITO_READ_ONLY = "arn:aws:iam::aws:policy/AmazonCognitoReadOnly"
    AMAZON_COGNITO_UNAUTHENTICATED_IDENTITIES = "arn:aws:iam::aws:policy/AmazonCognitoUnauthenticatedIdentities"
    AMAZON_CONNECT_CAMPAIGNS_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonConnectCampaignsServiceLinkedRolePolicy"
    AMAZON_CONNECT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonConnectReadOnlyAccess"
    AMAZON_CONNECT_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonConnectServiceLinkedRolePolicy"
    AMAZON_CONNECT_VOICE_ID_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonConnectVoiceIDFullAccess"
    AMAZON_CONNECT_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonConnect_FullAccess"
    AMAZON_DMS_CLOUD_WATCH_LOGS_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonDMSCloudWatchLogsRole"
    AMAZON_DMS_REDSHIFT_S3_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonDMSRedshiftS3Role"
    AMAZON_DMSVPC_MANAGEMENT_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonDMSVPCManagementRole"
    AMAZON_DRSVPC_MANAGEMENT = "arn:aws:iam::aws:policy/AmazonDRSVPCManagement"
    AMAZON_DETECTIVE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonDetectiveFullAccess"
    AMAZON_DETECTIVE_INVESTIGATOR_ACCESS = "arn:aws:iam::aws:policy/AmazonDetectiveInvestigatorAccess"
    AMAZON_DETECTIVE_MEMBER_ACCESS = "arn:aws:iam::aws:policy/AmazonDetectiveMemberAccess"
    AMAZON_DETECTIVE_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonDetectiveServiceLinkedRolePolicy"
    AMAZON_DEV_OPS_GURU_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonDevOpsGuruConsoleFullAccess"
    AMAZON_DEV_OPS_GURU_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonDevOpsGuruFullAccess"
    AMAZON_DEV_OPS_GURU_ORGANIZATIONS_ACCESS = "arn:aws:iam::aws:policy/AmazonDevOpsGuruOrganizationsAccess"
    AMAZON_DEV_OPS_GURU_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonDevOpsGuruReadOnlyAccess"
    AMAZON_DEV_OPS_GURU_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonDevOpsGuruServiceRolePolicy"
    AMAZON_DOC_DB_ELASTIC_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonDocDB-ElasticServiceRolePolicy"
    AMAZON_DOC_DB_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonDocDBConsoleFullAccess"
    AMAZON_DOC_DB_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonDocDBFullAccess"
    AMAZON_DOC_DB_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonDocDBReadOnlyAccess"
    AMAZON_DYNAMO_DB_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonDynamoDBFullAccess"
    AMAZON_DYNAMO_DB_FULL_ACCESSWITH_DATA_PIPELINE = "arn:aws:iam::aws:policy/AmazonDynamoDBFullAccesswithDataPipeline"
    AMAZON_DYNAMO_DB_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonDynamoDBReadOnlyAccess"
    AMAZON_EBSCSI_DRIVER_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonEBSCSIDriverPolicy"
    AMAZON_EC2_CONTAINER_REGISTRY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryFullAccess"
    AMAZON_EC2_CONTAINER_REGISTRY_POWER_USER = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryPowerUser"
    AMAZON_EC2_CONTAINER_REGISTRY_READ_ONLY = "arn:aws:iam::aws:policy/AmazonEC2ContainerRegistryReadOnly"
    AMAZON_EC2_CONTAINER_SERVICE_AUTOSCALE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceAutoscaleRole"
    AMAZON_EC2_CONTAINER_SERVICE_EVENTS_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceEventsRole"
    AMAZON_EC2_CONTAINER_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ContainerServiceFullAccess"
    AMAZON_EC2_CONTAINER_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceRole"
    AMAZON_EC2_CONTAINER_SERVICEFOR_EC2_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceforEC2Role"
    AMAZON_EC2_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2FullAccess"
    AMAZON_EC2_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ReadOnlyAccess"
    AMAZON_EC2_REPORTS_ACCESS = "arn:aws:iam::aws:policy/AmazonEC2ReportsAccess"
    AMAZON_EC2_ROLE_POLICY_FOR_LAUNCH_WIZARD = "arn:aws:iam::aws:policy/AmazonEC2RolePolicyForLaunchWizard"
    AMAZON_EC2_ROLEFOR_AWS_CODE_DEPLOY = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforAWSCodeDeploy"
    AMAZON_EC2_ROLEFOR_AWS_CODE_DEPLOY_LIMITED = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforAWSCodeDeployLimited"
    AMAZON_EC2_ROLEFOR_DATA_PIPELINE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforDataPipelineRole"
    AMAZON_EC2_ROLEFOR_SSM = "arn:aws:iam::aws:policy/service-role/AmazonEC2RoleforSSM"
    AMAZON_EC2_SPOT_FLEET_AUTOSCALE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetAutoscaleRole"
    AMAZON_EC2_SPOT_FLEET_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetRole"
    AMAZON_EC2_SPOT_FLEET_TAGGING_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonEC2SpotFleetTaggingRole"
    AMAZON_ECS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonECS_FullAccess"
    AMAZON_ECS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonECSServiceRolePolicy"
    AMAZON_ECS_TASK_EXECUTION_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonECSTaskExecutionRolePolicy"
    AMAZON_EKS_CLUSTER_POLICY = "arn:aws:iam::aws:policy/AmazonEKSClusterPolicy"
    AMAZON_EKS_CONNECTOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEKSConnectorServiceRolePolicy"
    AMAZON_EKS_FARGATE_POD_EXECUTION_ROLE_POLICY = "arn:aws:iam::aws:policy/AmazonEKSFargatePodExecutionRolePolicy"
    AMAZON_EKS_FOR_FARGATE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEKSForFargateServiceRolePolicy"
    AMAZON_EKS_LOCAL_OUTPOST_CLUSTER_POLICY = "arn:aws:iam::aws:policy/AmazonEKSLocalOutpostClusterPolicy"
    AMAZON_EKS_LOCAL_OUTPOST_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEKSLocalOutpostServiceRolePolicy"
    AMAZON_EKS_SERVICE_POLICY = "arn:aws:iam::aws:policy/AmazonEKSServicePolicy"
    AMAZON_EKS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEKSServiceRolePolicy"
    AMAZON_EKSVPC_RESOURCE_CONTROLLER = "arn:aws:iam::aws:policy/AmazonEKSVPCResourceController"
    AMAZON_EKS_WORKER_NODE_POLICY = "arn:aws:iam::aws:policy/AmazonEKSWorkerNodePolicy"
    AMAZON_EK_S_CN_I_POLICY = "arn:aws:iam::aws:policy/AmazonEKS_CNI_Policy"
    AMAZON_EMR_CLEANUP_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEMRCleanupPolicy"
    AMAZON_EMR_CONTAINERS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEMRContainersServiceRolePolicy"
    AMAZON_EMR_FULL_ACCESS_POLICY_V2 = "arn:aws:iam::aws:policy/AmazonEMRFullAccessPolicy_v2"
    AMAZON_EMR_READ_ONLY_ACCESS_POLICY_V2 = "arn:aws:iam::aws:policy/AmazonEMRReadOnlyAccessPolicy_v2"
    AMAZON_EMR_SERVERLESS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEMRServerlessServiceRolePolicy"
    AMAZON_EMR_SERVICE_POLICY_V2 = "arn:aws:iam::aws:policy/service-role/AmazonEMRServicePolicy_v2"
    AMAZON_ES_COGNITO_ACCESS = "arn:aws:iam::aws:policy/AmazonESCognitoAccess"
    AMAZON_ES_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonESFullAccess"
    AMAZON_ES_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonESReadOnlyAccess"
    AMAZON_ELASTI_CACHE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElastiCacheFullAccess"
    AMAZON_ELASTI_CACHE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElastiCacheReadOnlyAccess"
    AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticContainerRegistryPublicFullAccess"
    AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_POWER_USER = "arn:aws:iam::aws:policy/AmazonElasticContainerRegistryPublicPowerUser"
    AMAZON_ELASTIC_CONTAINER_REGISTRY_PUBLIC_READ_ONLY = "arn:aws:iam::aws:policy/AmazonElasticContainerRegistryPublicReadOnly"
    AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemClientFullAccess"
    AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemClientReadOnlyAccess"
    AMAZON_ELASTIC_FILE_SYSTEM_CLIENT_READ_WRITE_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemClientReadWriteAccess"
    AMAZON_ELASTIC_FILE_SYSTEM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemFullAccess"
    AMAZON_ELASTIC_FILE_SYSTEM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemReadOnlyAccess"
    AMAZON_ELASTIC_FILE_SYSTEM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonElasticFileSystemServiceRolePolicy"
    AMAZON_ELASTIC_FILE_SYSTEMS_UTILS = "arn:aws:iam::aws:policy/AmazonElasticFileSystemsUtils"
    AMAZON_ELASTIC_MAP_REDUCE_EDITORS_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceEditorsRole"
    AMAZON_ELASTIC_MAP_REDUCE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticMapReduceFullAccess"
    AMAZON_ELASTIC_MAP_REDUCE_PLACEMENT_GROUP_POLICY = "arn:aws:iam::aws:policy/AmazonElasticMapReducePlacementGroupPolicy"
    AMAZON_ELASTIC_MAP_REDUCE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticMapReduceReadOnlyAccess"
    AMAZON_ELASTIC_MAP_REDUCE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceRole"
    AMAZON_ELASTIC_MAP_REDUCEFOR_AUTO_SCALING_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforAutoScalingRole"
    AMAZON_ELASTIC_MAP_REDUCEFOR_EC2_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticMapReduceforEC2Role"
    AMAZON_ELASTIC_TRANSCODER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticTranscoderFullAccess"
    AMAZON_ELASTIC_TRANSCODER_JOBS_SUBMITTER = "arn:aws:iam::aws:policy/AmazonElasticTranscoderJobsSubmitter"
    AMAZON_ELASTIC_TRANSCODER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticTranscoderReadOnlyAccess"
    AMAZON_ELASTIC_TRANSCODER_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonElasticTranscoderRole"
    ELASTIC_TRANSCODER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticTranscoder_FullAccess"
    ELASTIC_TRANSCODER_JOBS_SUBMITTER = "arn:aws:iam::aws:policy/AmazonElasticTranscoder_JobsSubmitter"
    ELASTIC_TRANSCODER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonElasticTranscoder_ReadOnlyAccess"
    AMAZON_ELASTICSEARCH_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonElasticsearchServiceRolePolicy"
    AMAZON_EVENT_BRIDGE_API_DESTINATIONS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEventBridgeApiDestinationsServiceRolePolicy"
    AMAZON_EVENT_BRIDGE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgeFullAccess"
    AMAZON_EVENT_BRIDGE_PIPES_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgePipesFullAccess"
    AMAZON_EVENT_BRIDGE_PIPES_OPERATOR_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgePipesOperatorAccess"
    AMAZON_EVENT_BRIDGE_PIPES_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgePipesReadOnlyAccess"
    AMAZON_EVENT_BRIDGE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgeReadOnlyAccess"
    AMAZON_EVENT_BRIDGE_SCHEDULER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgeSchedulerFullAccess"
    AMAZON_EVENT_BRIDGE_SCHEDULER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgeSchedulerReadOnlyAccess"
    AMAZON_EVENT_BRIDGE_SCHEMAS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgeSchemasFullAccess"
    AMAZON_EVENT_BRIDGE_SCHEMAS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonEventBridgeSchemasReadOnlyAccess"
    AMAZON_EVENT_BRIDGE_SCHEMAS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonEventBridgeSchemasServiceRolePolicy"
    AMAZON_FIS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonFISServiceRolePolicy"
    AMAZON_F_SX_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonFSxConsoleFullAccess"
    AMAZON_F_SX_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonFSxConsoleReadOnlyAccess"
    AMAZON_F_SX_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonFSxFullAccess"
    AMAZON_F_SX_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonFSxReadOnlyAccess"
    AMAZON_F_SX_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonFSxServiceRolePolicy"
    AMAZON_FORECAST_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonForecastFullAccess"
    AMAZON_FRAUD_DETECTOR_FULL_ACCESS_POLICY = "arn:aws:iam::aws:policy/AmazonFraudDetectorFullAccessPolicy"
    AMAZON_FREE_RTOS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonFreeRTOSFullAccess"
    AMAZON_FREE_RTOSOTA_UPDATE = "arn:aws:iam::aws:policy/service-role/AmazonFreeRTOSOTAUpdate"
    AMAZON_GLACIER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonGlacierFullAccess"
    AMAZON_GLACIER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonGlacierReadOnlyAccess"
    AMAZON_GRAFANA_ATHENA_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonGrafanaAthenaAccess"
    AMAZON_GRAFANA_REDSHIFT_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonGrafanaRedshiftAccess"
    AMAZON_GRAFANA_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonGrafanaServiceLinkedRolePolicy"
    AMAZON_GUARD_DUTY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonGuardDutyFullAccess"
    AMAZON_GUARD_DUTY_MALWARE_PROTECTION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonGuardDutyMalwareProtectionServiceRolePolicy"
    AMAZON_GUARD_DUTY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonGuardDutyReadOnlyAccess"
    AMAZON_GUARD_DUTY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonGuardDutyServiceRolePolicy"
    AMAZON_HEALTH_LAKE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonHealthLakeFullAccess"
    AMAZON_HEALTH_LAKE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonHealthLakeReadOnlyAccess"
    AMAZON_HONEYCODE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonHoneycodeFullAccess"
    AMAZON_HONEYCODE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonHoneycodeReadOnlyAccess"
    AMAZON_HONEYCODE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonHoneycodeServiceRolePolicy"
    AMAZON_HONEYCODE_TEAM_ASSOCIATION_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonHoneycodeTeamAssociationFullAccess"
    AMAZON_HONEYCODE_TEAM_ASSOCIATION_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonHoneycodeTeamAssociationReadOnlyAccess"
    AMAZON_HONEYCODE_WORKBOOK_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonHoneycodeWorkbookFullAccess"
    AMAZON_HONEYCODE_WORKBOOK_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonHoneycodeWorkbookReadOnlyAccess"
    AMAZON_INSPECTOR2_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonInspector2FullAccess"
    AMAZON_INSPECTOR2_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonInspector2ReadOnlyAccess"
    AMAZON_INSPECTOR2_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonInspector2ServiceRolePolicy"
    AMAZON_INSPECTOR_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonInspectorFullAccess"
    AMAZON_INSPECTOR_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonInspectorReadOnlyAccess"
    AMAZON_INSPECTOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonInspectorServiceRolePolicy"
    AMAZON_KENDRA_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKendraFullAccess"
    AMAZON_KENDRA_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonKendraReadOnlyAccess"
    AMAZON_KEYSPACES_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKeyspacesFullAccess"
    AMAZON_KEYSPACES_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonKeyspacesReadOnlyAccess"
    AMAZON_KINESIS_ANALYTICS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisAnalyticsFullAccess"
    AMAZON_KINESIS_ANALYTICS_READ_ONLY = "arn:aws:iam::aws:policy/AmazonKinesisAnalyticsReadOnly"
    AMAZON_KINESIS_FIREHOSE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisFirehoseFullAccess"
    AMAZON_KINESIS_FIREHOSE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisFirehoseReadOnlyAccess"
    AMAZON_KINESIS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisFullAccess"
    AMAZON_KINESIS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisReadOnlyAccess"
    AMAZON_KINESIS_VIDEO_STREAMS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisVideoStreamsFullAccess"
    AMAZON_KINESIS_VIDEO_STREAMS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonKinesisVideoStreamsReadOnlyAccess"
    AMAZON_LAUNCH_WIZARD_FULLACCESS = "arn:aws:iam::aws:policy/AmazonLaunchWizard_Fullaccess"
    AMAZON_LEX_CHANNELS_ACCESS = "arn:aws:iam::aws:policy/aws-service-role/AmazonLexChannelsAccess"
    AMAZON_LEX_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonLexFullAccess"
    AMAZON_LEX_READ_ONLY = "arn:aws:iam::aws:policy/AmazonLexReadOnly"
    AMAZON_LEX_RUN_BOTS_ONLY = "arn:aws:iam::aws:policy/AmazonLexRunBotsOnly"
    AMAZON_LEX_V2_BOT_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonLexV2BotPolicy"
    AMAZON_LOOKOUT_EQUIPMENT_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutEquipmentFullAccess"
    AMAZON_LOOKOUT_EQUIPMENT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutEquipmentReadOnlyAccess"
    AMAZON_LOOKOUT_METRICS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutMetricsFullAccess"
    AMAZON_LOOKOUT_METRICS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutMetricsReadOnlyAccess"
    AMAZON_LOOKOUT_VISION_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutVisionConsoleFullAccess"
    AMAZON_LOOKOUT_VISION_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutVisionConsoleReadOnlyAccess"
    AMAZON_LOOKOUT_VISION_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutVisionFullAccess"
    AMAZON_LOOKOUT_VISION_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonLookoutVisionReadOnlyAccess"
    AMAZON_MCS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMCSFullAccess"
    AMAZON_MCS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMCSReadOnlyAccess"
    AMAZON_MQ_API_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMQApiFullAccess"
    AMAZON_MQ_API_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMQApiReadOnlyAccess"
    AMAZON_MQ_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMQFullAccess"
    AMAZON_MQ_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMQReadOnlyAccess"
    AMAZON_MQ_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonMQServiceRolePolicy"
    AMAZON_MSK_CONNECT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMSKConnectReadOnlyAccess"
    AMAZON_MSK_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMSKFullAccess"
    AMAZON_MSK_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMSKReadOnlyAccess"
    AMAZON_MWAA_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonMWAAServiceRolePolicy"
    AMAZON_MACHINE_LEARNING_BATCH_PREDICTIONS_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningBatchPredictionsAccess"
    AMAZON_MACHINE_LEARNING_CREATE_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningCreateOnlyAccess"
    AMAZON_MACHINE_LEARNING_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningFullAccess"
    AMAZON_MACHINE_LEARNING_MANAGE_REAL_TIME_ENDPOINT_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningManageRealTimeEndpointOnlyAccess"
    AMAZON_MACHINE_LEARNING_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningReadOnlyAccess"
    AMAZON_MACHINE_LEARNING_REAL_TIME_PREDICTION_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMachineLearningRealTimePredictionOnlyAccess"
    AMAZON_MACHINE_LEARNING_ROLEFOR_REDSHIFT_DATA_SOURCE = "arn:aws:iam::aws:policy/service-role/AmazonMachineLearningRoleforRedshiftDataSource"
    AMAZON_MACHINE_LEARNING_ROLEFOR_REDSHIFT_DATA_SOURCE_V3 = "arn:aws:iam::aws:policy/service-role/AmazonMachineLearningRoleforRedshiftDataSourceV3"
    AMAZON_MACIE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMacieFullAccess"
    AMAZON_MACIE_HANDSHAKE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonMacieHandshakeRole"
    AMAZON_MACIE_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonMacieServiceRole"
    AMAZON_MACIE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonMacieServiceRolePolicy"
    AMAZON_MANAGED_BLOCKCHAIN_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonManagedBlockchainConsoleFullAccess"
    AMAZON_MANAGED_BLOCKCHAIN_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonManagedBlockchainFullAccess"
    AMAZON_MANAGED_BLOCKCHAIN_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonManagedBlockchainReadOnlyAccess"
    AMAZON_MANAGED_BLOCKCHAIN_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonManagedBlockchainServiceRolePolicy"
    AMAZON_MECHANICAL_TURK_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMechanicalTurkFullAccess"
    AMAZON_MECHANICAL_TURK_READ_ONLY = "arn:aws:iam::aws:policy/AmazonMechanicalTurkReadOnly"
    AMAZON_MEMORY_DB_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMemoryDBFullAccess"
    AMAZON_MEMORY_DB_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMemoryDBReadOnlyAccess"
    AMAZON_MOBILE_ANALYTICS_FINANCIAL_REPORT_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsFinancialReportAccess"
    AMAZON_MOBILE_ANALYTICS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsFullAccess"
    AMAZON_MOBILE_ANALYTICS_NONFINANCIAL_REPORT_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsNon-financialReportAccess"
    AMAZON_MOBILE_ANALYTICS_WRITE_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonMobileAnalyticsWriteOnlyAccess"
    AMAZON_MONITRON_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonMonitronFullAccess"
    AMAZON_NIMBLE_STUDIO_LAUNCH_PROFILE_WORKER = "arn:aws:iam::aws:policy/AmazonNimbleStudio-LaunchProfileWorker"
    AMAZON_NIMBLE_STUDIO_STUDIO_ADMIN = "arn:aws:iam::aws:policy/AmazonNimbleStudio-StudioAdmin"
    AMAZON_NIMBLE_STUDIO_STUDIO_USER = "arn:aws:iam::aws:policy/AmazonNimbleStudio-StudioUser"
    AMAZON_OMICS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonOmicsFullAccess"
    AMAZON_OMICS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonOmicsReadOnlyAccess"
    AMAZON_OPEN_SEARCH_INGESTION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonOpenSearchIngestionServiceRolePolicy"
    AMAZON_OPEN_SEARCH_SERVERLESS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonOpenSearchServerlessServiceRolePolicy"
    AMAZON_OPEN_SEARCH_SERVICE_COGNITO_ACCESS = "arn:aws:iam::aws:policy/AmazonOpenSearchServiceCognitoAccess"
    AMAZON_OPEN_SEARCH_SERVICE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonOpenSearchServiceFullAccess"
    AMAZON_OPEN_SEARCH_SERVICE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonOpenSearchServiceReadOnlyAccess"
    AMAZON_OPEN_SEARCH_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonOpenSearchServiceRolePolicy"
    AMAZON_PERSONALIZE_FULL_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonPersonalizeFullAccess"
    AMAZON_POLLY_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonPollyFullAccess"
    AMAZON_POLLY_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonPollyReadOnlyAccess"
    AMAZON_PROMETHEUS_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonPrometheusConsoleFullAccess"
    AMAZON_PROMETHEUS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonPrometheusFullAccess"
    AMAZON_PROMETHEUS_QUERY_ACCESS = "arn:aws:iam::aws:policy/AmazonPrometheusQueryAccess"
    AMAZON_PROMETHEUS_REMOTE_WRITE_ACCESS = "arn:aws:iam::aws:policy/AmazonPrometheusRemoteWriteAccess"
    AMAZON_QLDB_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonQLDBConsoleFullAccess"
    AMAZON_QLDB_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonQLDBFullAccess"
    AMAZON_QLDB_READ_ONLY = "arn:aws:iam::aws:policy/AmazonQLDBReadOnly"
    AMAZON_RDS_BETA_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSBetaServiceRolePolicy"
    AMAZON_RDS_CUSTOM_PREVIEW_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSCustomPreviewServiceRolePolicy"
    AMAZON_RDS_CUSTOM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSCustomServiceRolePolicy"
    AMAZON_RDS_DATA_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRDSDataFullAccess"
    AMAZON_RDS_DIRECTORY_SERVICE_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonRDSDirectoryServiceAccess"
    AMAZON_RDS_ENHANCED_MONITORING_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonRDSEnhancedMonitoringRole"
    AMAZON_RDS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRDSFullAccess"
    AMAZON_RDS_PERFORMANCE_INSIGHTS_READ_ONLY = "arn:aws:iam::aws:policy/AmazonRDSPerformanceInsightsReadOnly"
    AMAZON_RDS_PREVIEW_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSPreviewServiceRolePolicy"
    AMAZON_RDS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRDSReadOnlyAccess"
    AMAZON_RDS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonRDSServiceRolePolicy"
    AMAZON_REDSHIFT_ALL_COMMANDS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRedshiftAllCommandsFullAccess"
    AMAZON_REDSHIFT_DATA_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRedshiftDataFullAccess"
    AMAZON_REDSHIFT_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRedshiftFullAccess"
    AMAZON_REDSHIFT_QUERY_EDITOR = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditor"
    AMAZON_REDSHIFT_QUERY_EDITOR_V2_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2FullAccess"
    AMAZON_REDSHIFT_QUERY_EDITOR_V2_NO_SHARING = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2NoSharing"
    AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_SHARING = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2ReadSharing"
    AMAZON_REDSHIFT_QUERY_EDITOR_V2_READ_WRITE_SHARING = "arn:aws:iam::aws:policy/AmazonRedshiftQueryEditorV2ReadWriteSharing"
    AMAZON_REDSHIFT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRedshiftReadOnlyAccess"
    AMAZON_REDSHIFT_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonRedshiftServiceLinkedRolePolicy"
    AMAZON_REKOGNITION_CUSTOM_LABELS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRekognitionCustomLabelsFullAccess"
    AMAZON_REKOGNITION_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRekognitionFullAccess"
    AMAZON_REKOGNITION_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRekognitionReadOnlyAccess"
    AMAZON_REKOGNITION_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonRekognitionServiceRole"
    AMAZON_ROUTE53_AUTO_NAMING_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53AutoNamingFullAccess"
    AMAZON_ROUTE53_AUTO_NAMING_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53AutoNamingReadOnlyAccess"
    AMAZON_ROUTE53_AUTO_NAMING_REGISTRANT_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53AutoNamingRegistrantAccess"
    AMAZON_ROUTE53_DOMAINS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53DomainsFullAccess"
    AMAZON_ROUTE53_DOMAINS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53DomainsReadOnlyAccess"
    AMAZON_ROUTE53_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53FullAccess"
    AMAZON_ROUTE53_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53ReadOnlyAccess"
    AMAZON_ROUTE53_RECOVERY_CLUSTER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryClusterFullAccess"
    AMAZON_ROUTE53_RECOVERY_CLUSTER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryClusterReadOnlyAccess"
    AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryControlConfigFullAccess"
    AMAZON_ROUTE53_RECOVERY_CONTROL_CONFIG_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryControlConfigReadOnlyAccess"
    AMAZON_ROUTE53_RECOVERY_READINESS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryReadinessFullAccess"
    AMAZON_ROUTE53_RECOVERY_READINESS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53RecoveryReadinessReadOnlyAccess"
    AMAZON_ROUTE53_RESOLVER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53ResolverFullAccess"
    AMAZON_ROUTE53_RESOLVER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonRoute53ResolverReadOnlyAccess"
    AMAZON_S3_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonS3FullAccess"
    AMAZON_S3_OBJECT_LAMBDA_EXECUTION_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonS3ObjectLambdaExecutionRolePolicy"
    AMAZON_S3_OUTPOSTS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonS3OutpostsFullAccess"
    AMAZON_S3_OUTPOSTS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonS3OutpostsReadOnlyAccess"
    AMAZON_S3_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonS3ReadOnlyAccess"
    AMAZON_SES_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSESFullAccess"
    AMAZON_SES_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSESReadOnlyAccess"
    AMAZON_SNS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSNSFullAccess"
    AMAZON_SNS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSNSReadOnlyAccess"
    AMAZON_SNS_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonSNSRole"
    AMAZON_SQS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSQSFullAccess"
    AMAZON_SQS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSQSReadOnlyAccess"
    AMAZON_SSM_AUTOMATION_APPROVER_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMAutomationApproverAccess"
    AMAZON_SSM_AUTOMATION_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonSSMAutomationRole"
    AMAZON_SSM_DIRECTORY_SERVICE_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMDirectoryServiceAccess"
    AMAZON_SSM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMFullAccess"
    AMAZON_SSM_MAINTENANCE_WINDOW_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonSSMMaintenanceWindowRole"
    AMAZON_SSM_MANAGED_EC2_INSTANCE_DEFAULT_POLICY = "arn:aws:iam::aws:policy/AmazonSSMManagedEC2InstanceDefaultPolicy"
    AMAZON_SSM_PATCH_ASSOCIATION = "arn:aws:iam::aws:policy/AmazonSSMPatchAssociation"
    AMAZON_SSM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonSSMReadOnlyAccess"
    AMAZON_SSM_MANAGED_INSTANCE_CORE = "arn:aws:iam::aws:policy/AmazonSSMManagedInstanceCore"
    AMAZON_SSM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonSSMServiceRolePolicy"
    AMAZON_SAGE_MAKER_ADMIN_SERVICE_CATALOG_PRODUCTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/AmazonSageMakerAdmin-ServiceCatalogProductsServiceRolePolicy"
    AMAZON_SAGE_MAKER_CANVAS_FORECAST_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerCanvasForecastAccess"
    AMAZON_SAGE_MAKER_CANVAS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSageMakerCanvasFullAccess"
    AMAZON_SAGE_MAKER_CORE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonSageMakerCoreServiceRolePolicy"
    AMAZON_SAGE_MAKER_EDGE_DEVICE_FLEET_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerEdgeDeviceFleetPolicy"
    AMAZON_SAGE_MAKER_FEATURE_STORE_ACCESS = "arn:aws:iam::aws:policy/AmazonSageMakerFeatureStoreAccess"
    AMAZON_SAGE_MAKER_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSageMakerFullAccess"
    AMAZON_SAGE_MAKER_GEOSPATIAL_EXECUTION_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerGeospatialExecutionRole"
    AMAZON_SAGE_MAKER_GEOSPATIAL_FULL_ACCESS = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerGeospatialFullAccess"
    AMAZON_SAGE_MAKER_GROUND_TRUTH_EXECUTION = "arn:aws:iam::aws:policy/AmazonSageMakerGroundTruthExecution"
    AMAZON_SAGE_MAKER_MECHANICAL_TURK_ACCESS = "arn:aws:iam::aws:policy/AmazonSageMakerMechanicalTurkAccess"
    AMAZON_SAGE_MAKER_MODEL_GOVERNANCE_USE_ACCESS = "arn:aws:iam::aws:policy/AmazonSageMakerModelGovernanceUseAccess"
    AMAZON_SAGE_MAKER_NOTEBOOKS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonSageMakerNotebooksServiceRolePolicy"
    AMAZON_SAGE_MAKER_PIPELINES_INTEGRATIONS = "arn:aws:iam::aws:policy/AmazonSageMakerPipelinesIntegrations"
    AMAZON_SAGE_MAKER_READ_ONLY = "arn:aws:iam::aws:policy/AmazonSageMakerReadOnly"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_API_GATEWAY_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsApiGatewayServiceRolePolicy"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CLOUDFORMATION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsCloudformationServiceRolePolicy"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_BUILD_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/AmazonSageMakerServiceCatalogProductsCodeBuildServiceRolePolicy"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_CODE_PIPELINE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsCodePipelineServiceRolePolicy"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_EVENTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsEventsServiceRolePolicy"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_FIREHOSE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsFirehoseServiceRolePolicy"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_GLUE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsGlueServiceRolePolicy"
    AMAZON_SAGE_MAKER_SERVICE_CATALOG_PRODUCTS_LAMBDA_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/AmazonSageMakerServiceCatalogProductsLambdaServiceRolePolicy"
    AMAZON_SECURITY_LAKE_PERMISSIONS_BOUNDARY = "arn:aws:iam::aws:policy/AmazonSecurityLakePermissionsBoundary"
    AMAZON_SUMERIAN_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonSumerianFullAccess"
    AMAZON_TEXTRACT_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonTextractFullAccess"
    AMAZON_TEXTRACT_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AmazonTextractServiceRole"
    AMAZON_TIMESTREAM_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonTimestreamConsoleFullAccess"
    AMAZON_TIMESTREAM_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonTimestreamFullAccess"
    AMAZON_TIMESTREAM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonTimestreamReadOnlyAccess"
    AMAZON_TRANSCRIBE_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonTranscribeFullAccess"
    AMAZON_TRANSCRIBE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonTranscribeReadOnlyAccess"
    AMAZON_VPC_CROSS_ACCOUNT_NETWORK_INTERFACE_OPERATIONS = "arn:aws:iam::aws:policy/AmazonVPCCrossAccountNetworkInterfaceOperations"
    AMAZON_VPC_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonVPCFullAccess"
    AMAZON_VPC_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonVPCReadOnlyAccess"
    AMAZON_WORK_DOCS_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkDocsFullAccess"
    AMAZON_WORK_DOCS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkDocsReadOnlyAccess"
    AMAZON_WORK_MAIL_EVENTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonWorkMailEventsServiceRolePolicy"
    AMAZON_WORK_MAIL_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkMailFullAccess"
    AMAZON_WORK_MAIL_MESSAGE_FLOW_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkMailMessageFlowFullAccess"
    AMAZON_WORK_MAIL_MESSAGE_FLOW_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkMailMessageFlowReadOnlyAccess"
    AMAZON_WORK_MAIL_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkMailReadOnlyAccess"
    AMAZON_WORK_SPACES_ADMIN = "arn:aws:iam::aws:policy/AmazonWorkSpacesAdmin"
    AMAZON_WORK_SPACES_APPLICATION_MANAGER_ADMIN_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkSpacesApplicationManagerAdminAccess"
    AMAZON_WORK_SPACES_SELF_SERVICE_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkSpacesSelfServiceAccess"
    AMAZON_WORK_SPACES_SERVICE_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkSpacesServiceAccess"
    AMAZON_WORK_SPACES_WEB_READ_ONLY = "arn:aws:iam::aws:policy/AmazonWorkSpacesWebReadOnly"
    AMAZON_WORK_SPACES_WEB_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AmazonWorkSpacesWebServiceRolePolicy"
    AMAZON_WORKSPACES_PCA_ACCESS = "arn:aws:iam::aws:policy/AmazonWorkspacesPCAAccess"
    AMAZON_ZOCALO_FULL_ACCESS = "arn:aws:iam::aws:policy/AmazonZocaloFullAccess"
    AMAZON_ZOCALO_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AmazonZocaloReadOnlyAccess"
    APP_INTEGRATIONS_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AppIntegrationsServiceLinkedRolePolicy"
    APP_RUNNER_NETWORKING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AppRunnerNetworkingServiceRolePolicy"
    APP_RUNNER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AppRunnerServiceRolePolicy"
    APPLICATION_AUTO_SCALING_FOR_AMAZON_APP_STREAM_ACCESS = "arn:aws:iam::aws:policy/service-role/ApplicationAutoScalingForAmazonAppStreamAccess"
    APPLICATION_DISCOVERY_SERVICE_CONTINUOUS_EXPORT_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ApplicationDiscoveryServiceContinuousExportServiceRolePolicy"
    AUTO_SCALING_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/AutoScalingConsoleFullAccess"
    AUTO_SCALING_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AutoScalingConsoleReadOnlyAccess"
    AUTO_SCALING_FULL_ACCESS = "arn:aws:iam::aws:policy/AutoScalingFullAccess"
    AUTO_SCALING_NOTIFICATION_ACCESS_ROLE = "arn:aws:iam::aws:policy/service-role/AutoScalingNotificationAccessRole"
    AUTO_SCALING_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/AutoScalingReadOnlyAccess"
    AUTO_SCALING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/AutoScalingServiceRolePolicy"
    AWS_GLUE_DATA_BREW_FULL_ACCESS_POLICY = "arn:aws:iam::aws:policy/AwsGlueDataBrewFullAccessPolicy"
    AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_POLICY = "arn:aws:iam::aws:policy/AwsGlueSessionUserRestrictedNotebookPolicy"
    AWS_GLUE_SESSION_USER_RESTRICTED_NOTEBOOK_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AwsGlueSessionUserRestrictedNotebookServiceRole"
    AWS_GLUE_SESSION_USER_RESTRICTED_POLICY = "arn:aws:iam::aws:policy/AwsGlueSessionUserRestrictedPolicy"
    AWS_GLUE_SESSION_USER_RESTRICTED_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/AwsGlueSessionUserRestrictedServiceRole"
    BATCH_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/BatchServiceRolePolicy"
    BILLING = "arn:aws:iam::aws:policy/job-function/Billing"
    CERTIFICATE_MANAGER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CertificateManagerServiceRolePolicy"
    CLIENT_VPN_SERVICE_CONNECTIONS_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ClientVPNServiceConnectionsRolePolicy"
    CLIENT_VPN_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ClientVPNServiceRolePolicy"
    CLOUD_FORMATION_STACK_SETS_ORG_ADMIN_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CloudFormationStackSetsOrgAdminServiceRolePolicy"
    CLOUD_FORMATION_STACK_SETS_ORG_MEMBER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CloudFormationStackSetsOrgMemberServiceRolePolicy"
    CLOUD_FRONT_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudFrontFullAccess"
    CLOUD_FRONT_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudFrontReadOnlyAccess"
    CLOUD_HSM_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CloudHSMServiceRolePolicy"
    CLOUD_SEARCH_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudSearchFullAccess"
    CLOUD_SEARCH_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudSearchReadOnlyAccess"
    CLOUD_TRAIL_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CloudTrailServiceRolePolicy"
    CLOUD_WATCH_CROSS_ACCOUNT_ACCESS = "arn:aws:iam::aws:policy/aws-service-role/CloudWatch-CrossAccountAccess"
    CLOUD_WATCH_ACTIONS_EC2_ACCESS = "arn:aws:iam::aws:policy/CloudWatchActionsEC2Access"
    CLOUD_WATCH_AGENT_ADMIN_POLICY = "arn:aws:iam::aws:policy/CloudWatchAgentAdminPolicy"
    CLOUD_WATCH_AGENT_SERVER_POLICY = "arn:aws:iam::aws:policy/CloudWatchAgentServerPolicy"
    CLOUD_WATCH_APPLICATION_INSIGHTS_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchApplicationInsightsFullAccess"
    CLOUD_WATCH_APPLICATION_INSIGHTS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchApplicationInsightsReadOnlyAccess"
    CLOUD_WATCH_AUTOMATIC_DASHBOARDS_ACCESS = "arn:aws:iam::aws:policy/CloudWatchAutomaticDashboardsAccess"
    CLOUD_WATCH_CROSS_ACCOUNT_SHARING_CONFIGURATION = "arn:aws:iam::aws:policy/CloudWatchCrossAccountSharingConfiguration"
    CLOUD_WATCH_EVENTS_BUILT_IN_TARGET_EXECUTION_ACCESS = "arn:aws:iam::aws:policy/service-role/CloudWatchEventsBuiltInTargetExecutionAccess"
    CLOUD_WATCH_EVENTS_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchEventsFullAccess"
    CLOUD_WATCH_EVENTS_INVOCATION_ACCESS = "arn:aws:iam::aws:policy/service-role/CloudWatchEventsInvocationAccess"
    CLOUD_WATCH_EVENTS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchEventsReadOnlyAccess"
    CLOUD_WATCH_EVENTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CloudWatchEventsServiceRolePolicy"
    CLOUD_WATCH_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchFullAccess"
    CLOUD_WATCH_INTERNET_MONITOR_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CloudWatchInternetMonitorServiceRolePolicy"
    CLOUD_WATCH_LAMBDA_INSIGHTS_EXECUTION_ROLE_POLICY = "arn:aws:iam::aws:policy/CloudWatchLambdaInsightsExecutionRolePolicy"
    CLOUD_WATCH_LOGS_CROSS_ACCOUNT_SHARING_CONFIGURATION = "arn:aws:iam::aws:policy/CloudWatchLogsCrossAccountSharingConfiguration"
    CLOUD_WATCH_LOGS_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchLogsFullAccess"
    CLOUD_WATCH_LOGS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchLogsReadOnlyAccess"
    CLOUD_WATCH_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchReadOnlyAccess"
    CLOUD_WATCH_SYNTHETICS_FULL_ACCESS = "arn:aws:iam::aws:policy/CloudWatchSyntheticsFullAccess"
    CLOUD_WATCH_SYNTHETICS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/CloudWatchSyntheticsReadOnlyAccess"
    CLOUDWATCH_APPLICATION_INSIGHTS_SERVICE_LINKED_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/CloudwatchApplicationInsightsServiceLinkedRolePolicy"
    COMPREHEND_DATA_ACCESS_ROLE_POLICY = "arn:aws:iam::aws:policy/service-role/ComprehendDataAccessRolePolicy"
    COMPREHEND_FULL_ACCESS = "arn:aws:iam::aws:policy/ComprehendFullAccess"
    COMPREHEND_MEDICAL_FULL_ACCESS = "arn:aws:iam::aws:policy/ComprehendMedicalFullAccess"
    COMPREHEND_READ_ONLY = "arn:aws:iam::aws:policy/ComprehendReadOnly"
    COMPUTE_OPTIMIZER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ComputeOptimizerReadOnlyAccess"
    COMPUTE_OPTIMIZER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ComputeOptimizerServiceRolePolicy"
    CONFIG_CONFORMS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ConfigConformsServiceRolePolicy"
    DAX_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/DAXServiceRolePolicy"
    DATA_SCIENTIST = "arn:aws:iam::aws:policy/job-function/DataScientist"
    DATABASE_ADMINISTRATOR = "arn:aws:iam::aws:policy/job-function/DatabaseAdministrator"
    DYNAMO_DB_CLOUD_WATCH_CONTRIBUTOR_INSIGHTS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/DynamoDBCloudWatchContributorInsightsServiceRolePolicy"
    DYNAMO_DB_KINESIS_REPLICATION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/DynamoDBKinesisReplicationServiceRolePolicy"
    DYNAMO_DB_REPLICATION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/DynamoDBReplicationServiceRolePolicy"
    EC2_FAST_LAUNCH_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/EC2FastLaunchServiceRolePolicy"
    EC2_FLEET_TIME_SHIFTABLE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/EC2FleetTimeShiftableServiceRolePolicy"
    EC2_INSTANCE_CONNECT = "arn:aws:iam::aws:policy/EC2InstanceConnect"
    EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER = "arn:aws:iam::aws:policy/EC2InstanceProfileForImageBuilder"
    EC2_INSTANCE_PROFILE_FOR_IMAGE_BUILDER_ECR_CONTAINER_BUILDS = "arn:aws:iam::aws:policy/EC2InstanceProfileForImageBuilderECRContainerBuilds"
    ECR_REPLICATION_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ECRReplicationServiceRolePolicy"
    EC2_IMAGE_BUILDER_CROSS_ACCOUNT_DISTRIBUTION_ACCESS = "arn:aws:iam::aws:policy/Ec2ImageBuilderCrossAccountDistributionAccess"
    EC2_INSTANCE_CONNECT_ENDPOINT = "arn:aws:iam::aws:policy/aws-service-role/Ec2InstanceConnectEndpoint"
    ELASTI_CACHE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ElastiCacheServiceRolePolicy"
    ELASTIC_LOAD_BALANCING_FULL_ACCESS = "arn:aws:iam::aws:policy/ElasticLoadBalancingFullAccess"
    ELASTIC_LOAD_BALANCING_READ_ONLY = "arn:aws:iam::aws:policy/ElasticLoadBalancingReadOnly"
    ELEMENTAL_ACTIVATIONS_DOWNLOAD_SOFTWARE_ACCESS = "arn:aws:iam::aws:policy/ElementalActivationsDownloadSoftwareAccess"
    ELEMENTAL_ACTIVATIONS_FULL_ACCESS = "arn:aws:iam::aws:policy/ElementalActivationsFullAccess"
    ELEMENTAL_ACTIVATIONS_GENERATE_LICENSES = "arn:aws:iam::aws:policy/ElementalActivationsGenerateLicenses"
    ELEMENTAL_ACTIVATIONS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ElementalActivationsReadOnlyAccess"
    ELEMENTAL_APPLIANCES_SOFTWARE_FULL_ACCESS = "arn:aws:iam::aws:policy/ElementalAppliancesSoftwareFullAccess"
    ELEMENTAL_APPLIANCES_SOFTWARE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ElementalAppliancesSoftwareReadOnlyAccess"
    ELEMENTAL_SUPPORT_CENTER_FULL_ACCESS = "arn:aws:iam::aws:policy/ElementalSupportCenterFullAccess"
    FMS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/FMSServiceRolePolicy"
    F_SX_DELETE_SERVICE_LINKED_ROLE_ACCESS = "arn:aws:iam::aws:policy/aws-service-role/FSxDeleteServiceLinkedRoleAccess"
    FUSION_DEV_INTERNAL_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/FusionDevInternalServiceRolePolicy"
    GAME_LIFT_GAME_SERVER_GROUP_POLICY = "arn:aws:iam::aws:policy/GameLiftGameServerGroupPolicy"
    GLOBAL_ACCELERATOR_FULL_ACCESS = "arn:aws:iam::aws:policy/GlobalAcceleratorFullAccess"
    GLOBAL_ACCELERATOR_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/GlobalAcceleratorReadOnlyAccess"
    GREENGRASS_OTA_UPDATE_ARTIFACT_ACCESS = "arn:aws:iam::aws:policy/service-role/GreengrassOTAUpdateArtifactAccess"
    GROUND_TRUTH_SYNTHETIC_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/GroundTruthSyntheticConsoleFullAccess"
    GROUND_TRUTH_SYNTHETIC_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/GroundTruthSyntheticConsoleReadOnlyAccess"
    HEALTH_ORGANIZATIONS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/Health_OrganizationsServiceRolePolicy"
    IAM_ACCESS_ADVISOR_READ_ONLY = "arn:aws:iam::aws:policy/IAMAccessAdvisorReadOnly"
    IAM_ACCESS_ANALYZER_FULL_ACCESS = "arn:aws:iam::aws:policy/IAMAccessAnalyzerFullAccess"
    IAM_ACCESS_ANALYZER_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/IAMAccessAnalyzerReadOnlyAccess"
    IAM_FULL_ACCESS = "arn:aws:iam::aws:policy/IAMFullAccess"
    IAM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/IAMReadOnlyAccess"
    IAM_SELF_MANAGE_SERVICE_SPECIFIC_CREDENTIALS = "arn:aws:iam::aws:policy/IAMSelfManageServiceSpecificCredentials"
    IAMUSER_CHANGE_PASSWORD = "arn:aws:iam::aws:policy/IAMUserChangePassword"
    IAMUSER_SSH_KEYS = "arn:aws:iam::aws:policy/IAMUserSSHKeys"
    IVS_RECORD_TO_S3 = "arn:aws:iam::aws:policy/aws-service-role/IVSRecordToS3"
    KAFKA_CONNECT_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/KafkaConnectServiceRolePolicy"
    KAFKA_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/KafkaServiceRolePolicy"
    LAKE_FORMATION_DATA_ACCESS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/LakeFormationDataAccessServiceRolePolicy"
    LEX_BOT_POLICY = "arn:aws:iam::aws:policy/aws-service-role/LexBotPolicy"
    LEX_CHANNEL_POLICY = "arn:aws:iam::aws:policy/aws-service-role/LexChannelPolicy"
    LIGHTSAIL_EXPORT_ACCESS = "arn:aws:iam::aws:policy/aws-service-role/LightsailExportAccess"
    MEDIA_PACKAGE_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/MediaPackageServiceRolePolicy"
    MEMORY_DB_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/MemoryDBServiceRolePolicy"
    MIGRATION_HUB_DMS_ACCESS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/MigrationHubDMSAccessServiceRolePolicy"
    MIGRATION_HUB_SMS_ACCESS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/MigrationHubSMSAccessServiceRolePolicy"
    MIGRATION_HUB_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/MigrationHubServiceRolePolicy"
    MONITRON_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/MonitronServiceRolePolicy"
    NEPTUNE_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/NeptuneConsoleFullAccess"
    NEPTUNE_FULL_ACCESS = "arn:aws:iam::aws:policy/NeptuneFullAccess"
    NEPTUNE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/NeptuneReadOnlyAccess"
    NETWORK_ADMINISTRATOR = "arn:aws:iam::aws:policy/job-function/NetworkAdministrator"
    OAM_FULL_ACCESS = "arn:aws:iam::aws:policy/OAMFullAccess"
    OAM_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/OAMReadOnlyAccess"
    POWER_USER_ACCESS = "arn:aws:iam::aws:policy/PowerUserAccess"
    QUICK_SIGHT_ACCESS_FOR_S3_STORAGE_MANAGEMENT_ANALYTICS_READ_ONLY = "arn:aws:iam::aws:policy/service-role/QuickSightAccessForS3StorageManagementAnalyticsReadOnly"
    RDS_CLOUD_HSM_AUTHORIZATION_ROLE = "arn:aws:iam::aws:policy/service-role/RDSCloudHsmAuthorizationRole"
    ROSA_MANAGE_SUBSCRIPTION = "arn:aws:iam::aws:policy/ROSAManageSubscription"
    READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ReadOnlyAccess"
    RESOURCE_GROUPS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ResourceGroupsServiceRolePolicy"
    RESOURCE_GROUPSAND_TAG_EDITOR_FULL_ACCESS = "arn:aws:iam::aws:policy/ResourceGroupsandTagEditorFullAccess"
    RESOURCE_GROUPSAND_TAG_EDITOR_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ResourceGroupsandTagEditorReadOnlyAccess"
    ROUTE53_RECOVERY_READINESS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/Route53RecoveryReadinessServiceRolePolicy"
    ROUTE53_RESOLVER_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/Route53ResolverServiceRolePolicy"
    S3_STORAGE_LENS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/S3StorageLensServiceRolePolicy"
    SECRETS_MANAGER_READ_WRITE = "arn:aws:iam::aws:policy/SecretsManagerReadWrite"
    SECURITY_AUDIT = "arn:aws:iam::aws:policy/SecurityAudit"
    SECURITY_LAKE_SERVICE_LINKED_ROLE = "arn:aws:iam::aws:policy/aws-service-role/SecurityLakeServiceLinkedRole"
    SERVER_MIGRATION_CONNECTOR = "arn:aws:iam::aws:policy/ServerMigrationConnector"
    SERVER_MIGRATION_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/ServerMigrationServiceRole"
    SERVICE_CATALOG_ADMIN_FULL_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogAdminFullAccess"
    SERVICE_CATALOG_ADMIN_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogAdminReadOnlyAccess"
    SERVICE_CATALOG_END_USER_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogEndUserAccess"
    SERVICE_CATALOG_END_USER_FULL_ACCESS = "arn:aws:iam::aws:policy/ServiceCatalogEndUserFullAccess"
    SERVER_MIGRATION_SERVICE_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/ServerMigrationServiceConsoleFullAccess"
    SERVER_MIGRATION_SERVICE_LAUNCH_ROLE = "arn:aws:iam::aws:policy/service-role/ServerMigrationServiceLaunchRole"
    SERVER_MIGRATION_SERVICE_ROLE_FOR_INSTANCE_VALIDATION = "arn:aws:iam::aws:policy/service-role/ServerMigrationServiceRoleForInstanceValidation"
    AWS_SERVER_MIGRATION_SERVICE_ROLE = "arn:aws:iam::aws:policy/service-role/ServerMigration_ServiceRole"
    SERVICE_QUOTAS_FULL_ACCESS = "arn:aws:iam::aws:policy/ServiceQuotasFullAccess"
    SERVICE_QUOTAS_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/ServiceQuotasReadOnlyAccess"
    SERVICE_QUOTAS_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/ServiceQuotasServiceRolePolicy"
    SIMPLE_WORKFLOW_FULL_ACCESS = "arn:aws:iam::aws:policy/SimpleWorkflowFullAccess"
    SUPPORT_USER = "arn:aws:iam::aws:policy/job-function/SupportUser"
    SYSTEM_ADMINISTRATOR = "arn:aws:iam::aws:policy/job-function/SystemAdministrator"
    TRANSLATE_FULL_ACCESS = "arn:aws:iam::aws:policy/TranslateFullAccess"
    TRANSLATE_READ_ONLY = "arn:aws:iam::aws:policy/TranslateReadOnly"
    VM_IMPORT_EXPORT_ROLE_FOR_AWS_CONNECTOR = "arn:aws:iam::aws:policy/service-role/VMImportExportRoleForAWSConnector"
    VIEW_ONLY_ACCESS = "arn:aws:iam::aws:policy/job-function/ViewOnlyAccess"
    WAF_LOGGING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/WAFLoggingServiceRolePolicy"
    WAF_REGIONAL_LOGGING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/WAFRegionalLoggingServiceRolePolicy"
    WAFV2_LOGGING_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/aws-service-role/WAFV2LoggingServiceRolePolicy"
    WELL_ARCHITECTED_CONSOLE_FULL_ACCESS = "arn:aws:iam::aws:policy/WellArchitectedConsoleFullAccess"
    WELL_ARCHITECTED_CONSOLE_READ_ONLY_ACCESS = "arn:aws:iam::aws:policy/WellArchitectedConsoleReadOnlyAccess"
    WORK_LINK_SERVICE_ROLE_POLICY = "arn:aws:iam::aws:policy/WorkLinkServiceRolePolicy"
